// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <signature.h>
#include <sbkcontainer.h>
#include <sbkstaticstrings.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysidecleanup.h>
#include <pysideqenum.h>
#include <feature_select.h>
#include <pysidestaticstrings.h>
#include "pyside6_qtcore_python.h"

#include <QAnyStringView>
#include <QHash>
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <QtCore/qlatin1stringview.h>
#include <qabstracteventdispatcher.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qcborvalue.h>
#include <qchar.h>
#include <qcommandlineoption.h>
#include <qfileinfo.h>
#include <qitemselectionmodel.h>
#include <qjsonobject.h>
#include <qlocale.h>
#include <qlogging.h>
#include <qmath.h>
#include <qmimetype.h>
#include <qnamespace.h>
#include <qnumeric.h>
#include <qobject.h>
#include <qpoint.h>
#include <qstorageinfo.h>
#include <qtimezone.h>
#include <qttranslation.h>
#include <qtversion.h>
#include <qurl.h>
#include <qvariant.h>
#include <qxmlstream.h>
#include <utility>


// Extra includes
#include <pysidemetatype.h>
#include <pysideutils.h>
#include <qloggingcategory.h>
#include <signalmanager.h>
#include "qtcorehelper.h"

// Current module's type array.
Shiboken::Module::TypeInitStruct *SbkPySide6_QtCoreTypeStructs = nullptr;
// Backwards compatible structure with identical indexing.
PyTypeObject **SbkPySide6_QtCoreTypes = nullptr;
// Current module's PyObject pointer.
PyObject *SbkPySide6_QtCoreModuleObject = nullptr;
// Current module's converter array.
SbkConverter **SbkPySide6_QtCoreTypeConverters = nullptr;

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (include-pyside)]
#include <pysideinit.h>
#include <limits>
#include "glue/core_snippets_p.h"
// END of custom code block [file: ../glue/qtcore.cpp (include-pyside)]
// ========================================================================
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (qarg_helper)]

// Helper for the Q_ARG/Q_RETURN_ARG functions, creating a meta type
// and instance.
struct QArgData
{
    operator bool() const { return metaType.isValid() && data != nullptr; }

    QMetaType metaType;
    void *data = nullptr;
};

QArgData qArgDataFromPyType(PyObject *t)
{
    QArgData result;
    const char *typeName{};
    if (PyType_Check(t)) {
        auto *pyType = reinterpret_cast<PyTypeObject *>(t);
        typeName = pyType->tp_name;
        result.metaType = PySide::qMetaTypeFromPyType(pyType);
    } else if (PyUnicode_Check(t)) {
        typeName = Shiboken::String::toCString(t);
        result.metaType = QMetaType::fromName(typeName);
    } else {
        PyErr_Format(PyExc_RuntimeError, "%s: Parameter should be a type or type string.",
                     __FUNCTION__);
        return result;
    }

    if (!result.metaType.isValid()) {
        PyErr_Format(PyExc_RuntimeError, "%s: Unable to find a QMetaType for \"%s\".",
                     __FUNCTION__, typeName);
        return result;
    }

    result.data = result.metaType.create();
    if (result.data == nullptr) {
        PyErr_Format(PyExc_RuntimeError, "%s: Unable to create an instance of \"%s\" (%s).",
                     __FUNCTION__, typeName, result.metaType.name());
        return result;
    }
    return result;
}
// END of custom code block [file: ../glue/qtcore.cpp (qarg_helper)]
// ========================================================================
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (darwin_permission_plugin)]
#ifdef Q_OS_DARWIN
#include<QtCore/qplugin.h>
// register the static plugin and setup its metadata
Q_IMPORT_PLUGIN(QDarwinCameraPermissionPlugin)
Q_IMPORT_PLUGIN(QDarwinMicrophonePermissionPlugin)
Q_IMPORT_PLUGIN(QDarwinBluetoothPermissionPlugin)
Q_IMPORT_PLUGIN(QDarwinContactsPermissionPlugin)
Q_IMPORT_PLUGIN(QDarwinCalendarPermissionPlugin)
#endif
// END of custom code block [file: ../glue/qtcore.cpp (darwin_permission_plugin)]
// ========================================================================
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (qvariant-conversion)]
static QVariant QVariant_convertToVariantMap(PyObject *map)
{
    Py_ssize_t pos = 0;
    Shiboken::AutoDecRef keys(PyDict_Keys(map));
    if (!QVariant_isStringList(keys))
        return {};
    PyObject *key;
    PyObject *value;
    QMap<QString,QVariant> ret;
    while (PyDict_Next(map, &pos, &key, &value)) {
        ::QString cppKey;
Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
        ::QVariant cppValue;
Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        ret.insert(cppKey, cppValue);
    }
    return QVariant(ret);
}
static QVariant QVariant_convertToVariantList(PyObject *list)
{
    if (QVariant_isStringList(list)) {
        ::QList<QString> lst;
Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QString_IDX], list, &(lst));
        return QVariant(QStringList(lst));
    }
    QVariant valueList = QVariant_convertToValueList(list);
    if (valueList.isValid())
        return valueList;

    if (PySequence_Size(list) < 0) {
        // clear the error if < 0 which means no length at all
        PyErr_Clear();
        return {};
    }

    QList<QVariant> lst;
    Shiboken::AutoDecRef fast(PySequence_Fast(list, "Failed to convert QVariantList"));
    const Py_ssize_t size = PySequence_Fast_GET_SIZE(fast.object());
    for (Py_ssize_t i = 0; i < size; ++i) {
        PyObject *pyItem = PySequence_Fast_GET_ITEM(fast.object(), i);
        ::QVariant item;
Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyItem, &(item));
        lst.append(item);
    }
    return QVariant(lst);
}

using SpecificConverter = Shiboken::Conversions::SpecificConverter;

static std::optional<SpecificConverter> converterForQtType(const char *typeNameC)
{
    // Fix typedef "QGenericMatrix<3,3,float>" -> QMatrix3x3". The reverse
    // conversion happens automatically in QMetaType::fromName() in
    // QVariant_resolveMetaType().
    QByteArrayView typeNameV(typeNameC);
    if (typeNameV.startsWith("QGenericMatrix<") && typeNameV.endsWith(",float>")) {
        QByteArray typeName = typeNameV.toByteArray();
        typeName.remove(1, 7);
        typeName.remove(7, 1); // '<'
        typeName.chop(7);
        typeName.replace(',', 'x');
        SpecificConverter matrixConverter(typeName.constData());
        if (matrixConverter)
            return matrixConverter;
    }
    SpecificConverter converter(typeNameC);
    if (converter)
        return converter;
    return std::nullopt;
}
// END of custom code block [file: ../glue/qtcore.cpp (qvariant-conversion)]
// ========================================================================
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (qt-messagehandler)]
// Define a global variable to handle qInstallMessageHandler callback
static PyObject *qtmsghandler = nullptr;

static void msgHandlerCallback(QtMsgType type, const QMessageLogContext &ctx, const QString &msg)
{
    Shiboken::GilState state;
    Shiboken::AutoDecRef arglist(PyTuple_New(3));
    PyTuple_SET_ITEM(arglist, 0, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX])))->converter, &type));
    PyTuple_SET_ITEM(arglist, 1, Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX]), &ctx));
    QByteArray array = msg.toUtf8();  // Python handler requires UTF-8
    const char *data = array.constData();
    PyTuple_SET_ITEM(arglist, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), data));
    Shiboken::AutoDecRef ret(PyObject_CallObject(qtmsghandler, arglist));
}
static void QtCoreModuleExit()
{
    PySide::SignalManager::instance().clear();
}
// END of custom code block [file: ../glue/qtcore.cpp (qt-messagehandler)]
// ========================================================================
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (qlatin1string-check)]
static bool qLatin1StringCheck(PyObject *o)
{
    return PyUnicode_CheckExact(o) != 0
        && _PepUnicode_KIND(o) == PepUnicode_1BYTE_KIND;
}
// END of custom code block [file: ../glue/qtcore.cpp (qlatin1string-check)]
// ========================================================================
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (qt-registerresourcedata)]
QT_BEGIN_NAMESPACE
extern bool
qRegisterResourceData(int,
                      const unsigned char *,
                      const unsigned char *,
                      const unsigned char *);

extern bool
qUnregisterResourceData(int,
                        const unsigned char *,
                        const unsigned char *,
                        const unsigned char *);
QT_END_NAMESPACE
// END of custom code block [file: ../glue/qtcore.cpp (qt-registerresourcedata)]
// ========================================================================
// End of code injection

void cleanTypesAttributes() {
    static PyObject *attrName = Shiboken::PyName::qtStaticMetaObject();
    const int imax = SBK_QtCore_IDX_COUNT;
    for (int i = 0; i < imax && SbkPySide6_QtCoreTypeStructs[i].fullName != nullptr; ++i) {
        auto *pyType = reinterpret_cast<PyObject *>(SbkPySide6_QtCoreTypeStructs[i].type);
        if (pyType != nullptr && PyObject_HasAttr(pyType, attrName))
            PyObject_SetAttr(pyType, attrName, Py_None);
    }
}

// Global functions ------------------------------------------------------------
static PyObject *SbkQtCoreModule_QEnum(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QEnum";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QEnum(PyObject*)->PyObject*
    if (true) {
        overloadId = 0; // QEnum(PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QEnum(PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qt-qenum)]
            pyResult = PySide::QEnum::QEnumMacro(pyArg, false);
            // END of custom code block [file: ../glue/qtcore.cpp (qt-qenum)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_QFlag(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QFlag";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFlag(PyObject*)->PyObject*
    if (true) {
        overloadId = 0; // QFlag(PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QFlag(PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qt-qflag)]
            pyResult = PySide::QEnum::QEnumMacro(pyArg, true);
            // END of custom code block [file: ../glue/qtcore.cpp (qt-qflag)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_QT_TRANSLATE_NOOP(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QT_TRANSLATE_NOOP";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QT_TRANSLATE_NOOP", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QT_TRANSLATE_NOOP(PyObject,PyObject)->PyObject*
    if (numArgs == 2
        && true
        && true) {
        overloadId = 0; // QT_TRANSLATE_NOOP(PyObject,PyObject)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QT_TRANSLATE_NOOP(PyObject,PyObject)
            // Begin code injection
            // TEMPLATE - return_argument - START
            Py_INCREF(pyArgs[2-1]);
            pyResult = pyArgs[2-1];
            // TEMPLATE - return_argument - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_QT_TRANSLATE_NOOP3(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QT_TRANSLATE_NOOP3";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QT_TRANSLATE_NOOP3", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QT_TRANSLATE_NOOP3(PyObject,PyObject,PyObject)->PyObject*
    if (numArgs == 3
        && true
        && true
        && true) {
        overloadId = 0; // QT_TRANSLATE_NOOP3(PyObject,PyObject,PyObject)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QT_TRANSLATE_NOOP3(PyObject,PyObject,PyObject)
            // Begin code injection
            // TEMPLATE - return_argument - START
            Py_INCREF(pyArgs[2-1]);
            pyResult = pyArgs[2-1];
            // TEMPLATE - return_argument - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_QT_TRANSLATE_NOOP_UTF8(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QT_TRANSLATE_NOOP_UTF8";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QT_TRANSLATE_NOOP_UTF8(PyObject)->PyObject*
    if (true) {
        overloadId = 0; // QT_TRANSLATE_NOOP_UTF8(PyObject)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QT_TRANSLATE_NOOP_UTF8(PyObject)
            // Begin code injection
            // TEMPLATE - return_argument - START
            Py_INCREF(pyArg);
            pyResult = pyArg;
            // TEMPLATE - return_argument - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_QT_TR_NOOP(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QT_TR_NOOP";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QT_TR_NOOP(PyObject)->PyObject*
    if (true) {
        overloadId = 0; // QT_TR_NOOP(PyObject)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QT_TR_NOOP(PyObject)
            // Begin code injection
            // TEMPLATE - return_argument - START
            Py_INCREF(pyArg);
            pyResult = pyArg;
            // TEMPLATE - return_argument - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_QT_TR_NOOP_UTF8(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QT_TR_NOOP_UTF8";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QT_TR_NOOP_UTF8(PyObject)->PyObject*
    if (true) {
        overloadId = 0; // QT_TR_NOOP_UTF8(PyObject)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QT_TR_NOOP_UTF8(PyObject)
            // Begin code injection
            // TEMPLATE - return_argument - START
            Py_INCREF(pyArg);
            pyResult = pyArg;
            // TEMPLATE - return_argument - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_Q_ARG(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.Q_ARG";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Q_ARG", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Q_ARG(PyObject*,PyObject*)->QtCoreHelper::QGenericArgumentHolder
    if (numArgs == 2
        && true
        && true) {
        overloadId = 0; // Q_ARG(PyObject*,PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // Q_ARG(PyObject*,PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (q_arg)]
            const QArgData qArgData = qArgDataFromPyType(pyArgs[0]);
            if (!qArgData)
                return nullptr;

            switch (qArgData.metaType.id()) {
                case QMetaType::Bool:
                    *reinterpret_cast<bool *>(qArgData.data) = pyArgs[1] == Py_True;
                    break;
                case QMetaType::Int:
                    *reinterpret_cast<int *>(qArgData.data) = int(PyLong_AsLong(pyArgs[1]));
                    break;
                case QMetaType::Double:
                    *reinterpret_cast<double *>(qArgData.data) = PyFloat_AsDouble(pyArgs[1]);
                    break;
                case QMetaType::QString:
                    *reinterpret_cast<QString *>(qArgData.data) = PySide::pyUnicodeToQString(pyArgs[1]);
                    break;
                default: {
                    Shiboken::Conversions::SpecificConverter converter(qArgData.metaType.name());
                    const auto type = converter.conversionType();
                    // Copy for values, Pointer for objects
                    if (type == Shiboken::Conversions::SpecificConverter::InvalidConversion) {
                        PyErr_Format(PyExc_RuntimeError, "%s: Unable to find converter for \"%s\".",
                                     __FUNCTION__, qArgData.metaType.name());
                        return nullptr;
                    }
                    converter.toCpp(pyArgs[1], qArgData.data);
                }
            }

            QtCoreHelper::QGenericArgumentHolder result(qArgData.metaType, qArgData.data);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), &result);
            // END of custom code block [file: ../glue/qtcore.cpp (q_arg)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_Q_RETURN_ARG(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.Q_RETURN_ARG";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q_RETURN_ARG(PyObject*)->QtCoreHelper::QGenericReturnArgumentHolder
    if (true) {
        overloadId = 0; // Q_RETURN_ARG(PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // Q_RETURN_ARG(PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (q_return_arg)]
            const QArgData qArgData = qArgDataFromPyType(pyArg);
            if (!qArgData)
                return nullptr;

            QtCoreHelper::QGenericReturnArgumentHolder result(qArgData.metaType, qArgData.data);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericReturnArgumentHolder_IDX]), &result);
            // END of custom code block [file: ../glue/qtcore.cpp (q_return_arg)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_SIGNAL(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.SIGNAL";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: SIGNAL(const char*)->str
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // SIGNAL(const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // SIGNAL(const char*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qt-signal)]
            pyResult = Shiboken::String::fromFormat("2%s",QMetaObject::normalizedSignature(cppArg0).constData());
            // END of custom code block [file: ../glue/qtcore.cpp (qt-signal)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_SLOT(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.SLOT";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: SLOT(const char*)->str
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // SLOT(const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // SLOT(const char*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qt-slot)]
            pyResult = Shiboken::String::fromFormat("1%s",QMetaObject::normalizedSignature(cppArg0).constData());
            // END of custom code block [file: ../glue/qtcore.cpp (qt-slot)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule___init_feature__(PyObject *self)
{
    SBK_UNUSED(self)
    static const char fullName[] = "PySide6.QtCore.__init_feature__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __init_feature__()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qt-init-feature)]
            PySide::Feature::init();
            // END of custom code block [file: ../glue/qtcore.cpp (qt-init-feature)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtCoreModule___moduleShutdown(PyObject *self)
{
    SBK_UNUSED(self)
    static const char fullName[] = "PySide6.QtCore.__moduleShutdown";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __moduleShutdown()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (moduleshutdown)]
            PySide::runCleanupFunctions();
            // END of custom code block [file: ../glue/qtcore.cpp (moduleshutdown)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtCoreModule_qAbs(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qAbs";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qAbs(double)->double
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // qAbs(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // qAbs(double)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qt-qabs)]
            double _abs = qAbs(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &_abs);
            // END of custom code block [file: ../glue/qtcore.cpp (qt-qabs)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qAddPostRoutine(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qAddPostRoutine";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qAddPostRoutine(PyObject*)
    if (true) {
        overloadId = 0; // qAddPostRoutine(PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // qAddPostRoutine(PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qt-addpostroutine)]
            PySide::addPostRoutine(pyArg);
            // END of custom code block [file: ../glue/qtcore.cpp (qt-addpostroutine)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtCoreModule_qCCritical(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qCCritical";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qCCritical", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qCCritical(PyObject*,const char*)
    if (numArgs == 2
        && true
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        overloadId = 0; // qCCritical(PyObject*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        SBK_UNUSED(cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // qCCritical(PyObject*,const char*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qloggingcategory_to_cpp)]
            // PYSIDE-2404: Usage of the `get()` function not necessary, the type exists.
                QLoggingCategory *category{nullptr};
                Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX].type,
                pyArgs[0], &(category));
            // END of custom code block [file: ../glue/qtcore.cpp (qloggingcategory_to_cpp)]
            // ========================================================================
            qCCritical((*category), "%s", cppArg1);
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtCoreModule_qCDebug(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qCDebug";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qCDebug", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qCDebug(PyObject*,const char*)
    if (numArgs == 2
        && true
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        overloadId = 0; // qCDebug(PyObject*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        SBK_UNUSED(cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // qCDebug(PyObject*,const char*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qloggingcategory_to_cpp)]
            // PYSIDE-2404: Usage of the `get()` function not necessary, the type exists.
                QLoggingCategory *category{nullptr};
                Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX].type,
                pyArgs[0], &(category));
            // END of custom code block [file: ../glue/qtcore.cpp (qloggingcategory_to_cpp)]
            // ========================================================================
            qCDebug((*category), "%s", cppArg1);
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtCoreModule_qCInfo(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qCInfo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qCInfo", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qCInfo(PyObject*,const char*)
    if (numArgs == 2
        && true
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        overloadId = 0; // qCInfo(PyObject*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        SBK_UNUSED(cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // qCInfo(PyObject*,const char*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qloggingcategory_to_cpp)]
            // PYSIDE-2404: Usage of the `get()` function not necessary, the type exists.
                QLoggingCategory *category{nullptr};
                Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX].type,
                pyArgs[0], &(category));
            // END of custom code block [file: ../glue/qtcore.cpp (qloggingcategory_to_cpp)]
            // ========================================================================
            qCInfo((*category), "%s", cppArg1);
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtCoreModule_qCWarning(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qCWarning";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qCWarning", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qCWarning(PyObject*,const char*)
    if (numArgs == 2
        && true
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        overloadId = 0; // qCWarning(PyObject*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        SBK_UNUSED(cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // qCWarning(PyObject*,const char*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qloggingcategory_to_cpp)]
            // PYSIDE-2404: Usage of the `get()` function not necessary, the type exists.
                QLoggingCategory *category{nullptr};
                Shiboken::Conversions::pythonToCppPointer(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX].type,
                pyArgs[0], &(category));
            // END of custom code block [file: ../glue/qtcore.cpp (qloggingcategory_to_cpp)]
            // ========================================================================
            qCWarning((*category), "%s", cppArg1);
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtCoreModule_qCompress(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qCompress";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:qCompress", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qCompress(PyBuffer,qsizetype,int=)->QByteArray
    // 1: qCompress(QByteArray,int=)->QByteArray
    if (numArgs >= 2
        && Shiboken::Buffer::checkType(pyArgs[0])
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // qCompress(const uchar*,qsizetype,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // qCompress(const uchar*,qsizetype,int)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // qCompress(QByteArray,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // qCompress(QByteArray,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qCompress(const uchar * data, qsizetype nbytes, int compressionLevel)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_compressionLevel = Shiboken::String::createStaticString("compressionLevel");
                if (PyDict_Contains(kwds, key_compressionLevel) != 0) {
                    value = PyDict_GetItem(kwds, key_compressionLevel);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_compressionLevel);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_compressionLevel);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qCompress(const uchar*,qsizetype,int)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qcompress-buffer)]
                auto *ptr = reinterpret_cast<uchar*>(Shiboken::Buffer::getPointer(pyArgs[1-1]));
                QByteArray compressed = qCompress(ptr, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &compressed);
                // END of custom code block [file: ../glue/qtcore.cpp (qcompress-buffer)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // qCompress(const QByteArray & data, int compressionLevel)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_compressionLevel = Shiboken::String::createStaticString("compressionLevel");
                if (PyDict_Contains(kwds, key_compressionLevel) != 0) {
                    value = PyDict_GetItem(kwds, key_compressionLevel);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_compressionLevel);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_compressionLevel);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1 = -1;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qCompress(QByteArray,int)
                QByteArray cppResult = qCompress(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qCritical(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qCritical";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qCritical(const char*)
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // qCritical(const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // qCritical(const char*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (use-stream-for-format-security)]
            // Uses the stream version for security reasons
            // see gcc man page at -Wformat-security
            Py_BEGIN_ALLOW_THREADS
            qCritical() << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (use-stream-for-format-security)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtCoreModule_qDebug(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qDebug";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qDebug(const char*)
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // qDebug(const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // qDebug(const char*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (use-stream-for-format-security)]
            // Uses the stream version for security reasons
            // see gcc man page at -Wformat-security
            Py_BEGIN_ALLOW_THREADS
            qDebug() << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (use-stream-for-format-security)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtCoreModule_qFastCos(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qFastCos";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qFastCos(qreal)->qreal
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // qFastCos(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qFastCos(qreal)
            qreal cppResult = qFastCos(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qFastSin(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qFastSin";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qFastSin(qreal)->qreal
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // qFastSin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qFastSin(qreal)
            qreal cppResult = qFastSin(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qFatal(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qFatal";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qFatal(const char*)
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // qFatal(const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // qFatal(const char*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qfatal)]
            // qFatal doesn't have a stream version, so we do a
            // qWarning call followed by a qFatal() call using a
            // literal.
            Py_BEGIN_ALLOW_THREADS
            qWarning() << cppArg0;
            qFatal("[A qFatal() call was made from Python code]");
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (qfatal)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtCoreModule_qFormatLogMessage(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qFormatLogMessage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qFormatLogMessage", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qFormatLogMessage(QtMsgType,QMessageLogContext,QString)->QString
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogContext_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // qFormatLogMessage(QtMsgType,QMessageLogContext,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QtMsgType cppArg0{QtDebugMsg};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QMessageLogContext *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qFormatLogMessage(QtMsgType,QMessageLogContext,QString)
            QString cppResult = qFormatLogMessage(cppArg0, *cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qFuzzyCompare(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qFuzzyCompare";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qFuzzyCompare", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qFuzzyCompare(double,double)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        overloadId = 0; // qFuzzyCompare(double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qFuzzyCompare(double,double)
            bool cppResult = qFuzzyCompare(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qFuzzyIsNull(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qFuzzyIsNull";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qFuzzyIsNull(double)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // qFuzzyIsNull(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qFuzzyIsNull(double)
            bool cppResult = qFuzzyIsNull(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qInstallMessageHandler(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qInstallMessageHandler";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qInstallMessageHandler(PyObject)->PyObject
    if (true) {
        overloadId = 0; // qInstallMessageHandler(PyObject)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // qInstallMessageHandler(PyObject)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qt-installmessagehandler)]
            if (pyArg == Py_None) {
              qInstallMessageHandler(0);
              pyResult = qtmsghandler ? qtmsghandler : Py_None;
              qtmsghandler = 0;
            } else if (!PyCallable_Check(pyArg)) {
              PyErr_SetString(PyExc_TypeError, "parameter must be callable");
            } else {
              pyResult = qtmsghandler ? qtmsghandler : Py_None;
              Py_INCREF(pyArg);
              qtmsghandler = pyArg;
              qInstallMessageHandler(msgHandlerCallback);
            }

            if (pyResult == Py_None)
                Py_INCREF(pyResult);
            // END of custom code block [file: ../glue/qtcore.cpp (qt-installmessagehandler)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qIsFinite(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qIsFinite";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qIsFinite(double)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // qIsFinite(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qIsFinite(double)
            bool cppResult = qIsFinite(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qIsInf(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qIsInf";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qIsInf(double)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // qIsInf(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qIsInf(double)
            bool cppResult = qIsInf(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qIsNaN(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qIsNaN";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qIsNaN(double)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // qIsNaN(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qIsNaN(double)
            bool cppResult = qIsNaN(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qIsNull(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qIsNull";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qIsNull(double)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // qIsNull(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qIsNull(double)
            bool cppResult = qIsNull(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qRegisterResourceData(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qRegisterResourceData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qRegisterResourceData", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qRegisterResourceData(int,PyBytes,PyBytes,PyBytes)->bool
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && PyBytes_Check(pyArgs[1])
        && PyBytes_Check(pyArgs[2])
        && PyBytes_Check(pyArgs[3])) {
        overloadId = 0; // qRegisterResourceData(int,PyBytes,PyBytes,PyBytes)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // qRegisterResourceData(int,PyBytes,PyBytes,PyBytes)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qt-qregisterresourcedata)]
            bool cppResult = qRegisterResourceData(cppArg0, reinterpret_cast<uchar *>(PyBytes_AS_STRING(pyArgs[2-1])),
                                                 reinterpret_cast<uchar *>(PyBytes_AS_STRING(pyArgs[3-1])),
                                                 reinterpret_cast<uchar *>(PyBytes_AS_STRING(pyArgs[4-1])));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            // END of custom code block [file: ../glue/qtcore.cpp (qt-qregisterresourcedata)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qSetMessagePattern(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qSetMessagePattern";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qSetMessagePattern(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // qSetMessagePattern(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qSetMessagePattern(QString)
            qSetMessagePattern(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtCoreModule_qUncompress(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qUncompress";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qUncompress", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qUncompress(PyBuffer,qsizetype)->QByteArray
    // 1: qUncompress(QByteArray)->QByteArray
    if (numArgs == 2
        && Shiboken::Buffer::checkType(pyArgs[0])
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // qUncompress(const uchar*,qsizetype)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 1; // qUncompress(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qUncompress(const uchar * data, qsizetype nbytes)
        {
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qUncompress(const uchar*,qsizetype)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (quncompress-buffer)]
                auto *ptr = reinterpret_cast<uchar*>(Shiboken::Buffer::getPointer(pyArgs[1-1]));
                QByteArray uncompressed = qUncompress(ptr, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &uncompressed);
                // END of custom code block [file: ../glue/qtcore.cpp (quncompress-buffer)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // qUncompress(const QByteArray & data)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // qUncompress(QByteArray)
                QByteArray cppResult = qUncompress(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qUnregisterResourceData(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qUnregisterResourceData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qUnregisterResourceData", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qUnregisterResourceData(int,PyBytes,PyBytes,PyBytes)->bool
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && PyBytes_Check(pyArgs[1])
        && PyBytes_Check(pyArgs[2])
        && PyBytes_Check(pyArgs[3])) {
        overloadId = 0; // qUnregisterResourceData(int,PyBytes,PyBytes,PyBytes)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // qUnregisterResourceData(int,PyBytes,PyBytes,PyBytes)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qt-qunregisterresourcedata)]
            bool cppResult = qUnregisterResourceData(cppArg0, reinterpret_cast<uchar *>(PyBytes_AS_STRING(pyArgs[2-1])),
                                                 reinterpret_cast<uchar *>(PyBytes_AS_STRING(pyArgs[3-1])),
                                                 reinterpret_cast<uchar *>(PyBytes_AS_STRING(pyArgs[4-1])));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            // END of custom code block [file: ../glue/qtcore.cpp (qt-qunregisterresourcedata)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qVersion(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.qVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // qVersion()
            const char * cppResult = qVersion();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *SbkQtCoreModule_qWarning(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qWarning";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: qWarning(const char*)
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // qWarning(const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // qWarning(const char*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (use-stream-for-format-security)]
            // Uses the stream version for security reasons
            // see gcc man page at -Wformat-security
            Py_BEGIN_ALLOW_THREADS
            qWarning() << cppArg0;
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (use-stream-for-format-security)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtCoreModule_qtTrId(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.qtTrId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:qtTrId", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qtTrId(const char*,int=)->QString
    if (numArgs >= 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qtTrId(const char*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // qtTrId(const char*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_n = Shiboken::String::createStaticString("n");
            if (PyDict_Contains(kwds, key_n) != 0) {
                value = PyDict_GetItem(kwds, key_n);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_n);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_n);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = -1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qtTrId(const char*,int)
            QString cppResult = qtTrId(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static PyMethodDef QtCore_methods[] = {
    {"QEnum", reinterpret_cast<PyCFunction>(SbkQtCoreModule_QEnum), METH_O, nullptr},
    {"QFlag", reinterpret_cast<PyCFunction>(SbkQtCoreModule_QFlag), METH_O, nullptr},
    {"QT_TRANSLATE_NOOP", reinterpret_cast<PyCFunction>(SbkQtCoreModule_QT_TRANSLATE_NOOP), METH_VARARGS, nullptr},
    {"QT_TRANSLATE_NOOP3", reinterpret_cast<PyCFunction>(SbkQtCoreModule_QT_TRANSLATE_NOOP3), METH_VARARGS, nullptr},
    {"QT_TRANSLATE_NOOP_UTF8", reinterpret_cast<PyCFunction>(SbkQtCoreModule_QT_TRANSLATE_NOOP_UTF8), METH_O, nullptr},
    {"QT_TR_NOOP", reinterpret_cast<PyCFunction>(SbkQtCoreModule_QT_TR_NOOP), METH_O, nullptr},
    {"QT_TR_NOOP_UTF8", reinterpret_cast<PyCFunction>(SbkQtCoreModule_QT_TR_NOOP_UTF8), METH_O, nullptr},
    {"Q_ARG", reinterpret_cast<PyCFunction>(SbkQtCoreModule_Q_ARG), METH_VARARGS, nullptr},
    {"Q_RETURN_ARG", reinterpret_cast<PyCFunction>(SbkQtCoreModule_Q_RETURN_ARG), METH_O, nullptr},
    {"SIGNAL", reinterpret_cast<PyCFunction>(SbkQtCoreModule_SIGNAL), METH_O, nullptr},
    {"SLOT", reinterpret_cast<PyCFunction>(SbkQtCoreModule_SLOT), METH_O, nullptr},
    {"__init_feature__", reinterpret_cast<PyCFunction>(SbkQtCoreModule___init_feature__), METH_NOARGS, nullptr},
    {"__moduleShutdown", reinterpret_cast<PyCFunction>(SbkQtCoreModule___moduleShutdown), METH_NOARGS, nullptr},
    {"qAbs", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qAbs), METH_O, nullptr},
    {"qAddPostRoutine", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qAddPostRoutine), METH_O, nullptr},
    {"qCCritical", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qCCritical), METH_VARARGS, nullptr},
    {"qCDebug", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qCDebug), METH_VARARGS, nullptr},
    {"qCInfo", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qCInfo), METH_VARARGS, nullptr},
    {"qCWarning", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qCWarning), METH_VARARGS, nullptr},
    {"qCompress", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qCompress), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qCritical", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qCritical), METH_O, nullptr},
    {"qDebug", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qDebug), METH_O, nullptr},
    {"qFastCos", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qFastCos), METH_O, nullptr},
    {"qFastSin", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qFastSin), METH_O, nullptr},
    {"qFatal", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qFatal), METH_O, nullptr},
    {"qFormatLogMessage", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qFormatLogMessage), METH_VARARGS, nullptr},
    {"qFuzzyCompare", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qFuzzyCompare), METH_VARARGS, nullptr},
    {"qFuzzyIsNull", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qFuzzyIsNull), METH_O, nullptr},
    {"qInstallMessageHandler", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qInstallMessageHandler), METH_O, nullptr},
    {"qIsFinite", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qIsFinite), METH_O, nullptr},
    {"qIsInf", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qIsInf), METH_O, nullptr},
    {"qIsNaN", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qIsNaN), METH_O, nullptr},
    {"qIsNull", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qIsNull), METH_O, nullptr},
    {"qRegisterResourceData", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qRegisterResourceData), METH_VARARGS, nullptr},
    {"qSetMessagePattern", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qSetMessagePattern), METH_O, nullptr},
    {"qUncompress", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qUncompress), METH_VARARGS, nullptr},
    {"qUnregisterResourceData", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qUnregisterResourceData), METH_VARARGS, nullptr},
    {"qVersion", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qVersion), METH_NOARGS, nullptr},
    {"qWarning", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qWarning), METH_O, nullptr},
    {"qtTrId", reinterpret_cast<PyCFunction>(SbkQtCoreModule_qtTrId), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
PyTypeObject *init_QtCoreQt(PyObject *module);
PyTypeObject *init_QXmlStreamWriter(PyObject *module);
PyTypeObject *init_QXmlStreamReader(PyObject *module);
PyTypeObject *init_QXmlStreamNotationDeclaration(PyObject *module);
PyTypeObject *init_QXmlStreamNamespaceDeclaration(PyObject *module);
PyTypeObject *init_QXmlStreamEntityResolver(PyObject *module);
PyTypeObject *init_QXmlStreamEntityDeclaration(PyObject *module);
PyTypeObject *init_QXmlStreamAttributes(PyObject *module);
PyTypeObject *init_QXmlStreamAttribute(PyObject *module);
#if QT_CONFIG(thread)
PyTypeObject *init_QWriteLocker(PyObject *module);
#endif
PyTypeObject *init_QVersionNumber(PyObject *module);
PyTypeObject *init_QUuid(PyObject *module);
PyTypeObject *init_QUrlQuery(PyObject *module);
PyTypeObject *init_QTime(PyObject *module);
PyTypeObject *init_QTextStreamManipulator(PyObject *module);
PyTypeObject *init_QTextBoundaryFinder(PyObject *module);
PyTypeObject *init_QTemporaryDir(PyObject *module);
#ifndef QT_NO_SYSTEMSEMAPHORE
PyTypeObject *init_QSystemSemaphore(PyObject *module);
#endif
PyTypeObject *init_QSysInfo(PyObject *module);
PyTypeObject *init_QStringConverterBase(PyObject *module);
PyTypeObject *init_QStringConverterBase_State(PyObject *enclosingClass);
PyTypeObject *init_QStringConverter(PyObject *module);
PyTypeObject *init_QStringEncoder(PyObject *module);
PyTypeObject *init_QStringDecoder(PyObject *module);
PyTypeObject *init_QStorageInfo(PyObject *module);
PyTypeObject *init_QStandardPaths(PyObject *module);
PyTypeObject *init_QSocketDescriptor(PyObject *module);
PyTypeObject *init_QSizeF(PyObject *module);
PyTypeObject *init_QSize(PyObject *module);
PyTypeObject *init_QSignalBlocker(PyObject *module);
#if QT_CONFIG(thread)
PyTypeObject *init_QSemaphoreReleaser(PyObject *module);
#endif
#if QT_CONFIG(thread)
PyTypeObject *init_QSemaphore(PyObject *module);
#endif
#if QT_CONFIG(thread)
PyTypeObject *init_QRunnable(PyObject *module);
#endif
PyTypeObject *init_QRegularExpressionMatchIterator(PyObject *module);
PyTypeObject *init_QRegularExpressionMatch(PyObject *module);
PyTypeObject *init_QRegularExpression(PyObject *module);
PyTypeObject *init_QRectF(PyObject *module);
PyTypeObject *init_QRect(PyObject *module);
#if QT_CONFIG(thread)
PyTypeObject *init_QReadLocker(PyObject *module);
#endif
PyTypeObject *init_QRandomGenerator(PyObject *module);
PyTypeObject *init_QRandomGenerator64(PyObject *module);
#if QT_CONFIG(processenvironment)
PyTypeObject *init_QProcessEnvironment(PyObject *module);
#endif
PyTypeObject *init_QPointF(PyObject *module);
PyTypeObject *init_QPoint(PyObject *module);
PyTypeObject *init_QPersistentModelIndex(PyObject *module);
#if QT_CONFIG(permissions)
PyTypeObject *init_QPermission(PyObject *module);
#endif
PyTypeObject *init_QOperatingSystemVersionBase(PyObject *module);
PyTypeObject *init_QOperatingSystemVersion(PyObject *module);
PyTypeObject *init_QOperatingSystemVersionStaticFields(PyObject *module);
PyTypeObject *init_QNativeIpcKey(PyObject *module);
PyTypeObject *init_QNativeIpcKeyStaticFields(PyObject *module);
#if QT_CONFIG(thread)
PyTypeObject *init_QtCoreHelper_QMutexLocker(PyObject *module);
#endif
PyTypeObject *init_QModelRoleData(PyObject *module);
PyTypeObject *init_QModelIndex(PyObject *module);
PyTypeObject *init_QMimeType(PyObject *module);
PyTypeObject *init_QMimeDatabase(PyObject *module);
#if QT_CONFIG(permissions)
PyTypeObject *init_QMicrophonePermission(PyObject *module);
#endif
PyTypeObject *init_QMetaType(PyObject *module);
PyTypeObject *init_QMetaProperty(PyObject *module);
PyTypeObject *init_QMetaEnum(PyObject *module);
PyTypeObject *init_QMetaClassInfo(PyObject *module);
PyTypeObject *init_QMessageLogContext(PyObject *module);
PyTypeObject *init_QMessageAuthenticationCode(PyObject *module);
PyTypeObject *init_QMarginsF(PyObject *module);
PyTypeObject *init_QMargins(PyObject *module);
PyTypeObject *init_QLoggingCategory(PyObject *module);
PyTypeObject *init_QLockFile(PyObject *module);
#if QT_CONFIG(permissions)
PyTypeObject *init_QLocationPermission(PyObject *module);
#endif
PyTypeObject *init_QLocale(PyObject *module);
PyTypeObject *init_QLocaleStaticFields(PyObject *module);
#if QT_CONFIG(timezone)
PyTypeObject *init_QTimeZone(PyObject *module);
PyTypeObject *init_QTimeZoneStaticFields(PyObject *module);
#endif
PyTypeObject *init_QResource(PyObject *module);
PyTypeObject *init_QLineF(PyObject *module);
PyTypeObject *init_QLine(PyObject *module);
PyTypeObject *init_QLibraryInfo(PyObject *module);
PyTypeObject *init_QKeyCombination(PyObject *module);
PyTypeObject *init_QJsonValue(PyObject *module);
PyTypeObject *init_QJsonParseError(PyObject *module);
PyTypeObject *init_QJsonDocument(PyObject *module);
PyTypeObject *init_QJsonArray(PyObject *module);
PyTypeObject *init_QItemSelectionRange(PyObject *module);
PyTypeObject *init_QItemSelection(PyObject *module);
PyTypeObject *init_QIODeviceBase(PyObject *module);
PyTypeObject *init_QTextStream(PyObject *module);
PyTypeObject *init_QHashSeed(PyObject *module);
PyTypeObject *init_QtCoreHelper_QGenericReturnArgumentHolder(PyObject *module);
PyTypeObject *init_QtCoreHelper_QGenericArgumentHolder(PyObject *module);
PyTypeObject *init_QGenericArgument(PyObject *module);
PyTypeObject *init_QMetaObject(PyObject *module);
PyTypeObject *init_QMetaObject_Connection(PyObject *enclosingClass);
PyTypeObject *init_QObject(PyObject *module);
PyTypeObject *init_QTranslator(PyObject *module);
PyTypeObject *init_QTimer(PyObject *module);
PyTypeObject *init_QTimeLine(PyObject *module);
#if QT_CONFIG(thread)
PyTypeObject *init_QThreadPool(PyObject *module);
#endif
PyTypeObject *init_QSocketNotifier(PyObject *module);
PyTypeObject *init_QSignalMapper(PyObject *module);
#ifndef QT_NO_SHAREDMEMORY
PyTypeObject *init_QSharedMemory(PyObject *module);
#endif
PyTypeObject *init_QSettings(PyObject *module);
PyTypeObject *init_QPluginLoader(PyObject *module);
PyTypeObject *init_QMimeData(PyObject *module);
PyTypeObject *init_QLibrary(PyObject *module);
PyTypeObject *init_QItemSelectionModel(PyObject *module);
PyTypeObject *init_QtCoreHelper_QIOPipe(PyObject *module);
PyTypeObject *init_QIODevice(PyObject *module);
#if QT_CONFIG(process)
PyTypeObject *init_QProcess(PyObject *module);
#endif
PyTypeObject *init_QProcess_UnixProcessParameters(PyObject *enclosingClass);
PyTypeObject *init_QMetaMethod(PyObject *module);
PyTypeObject *init_QGenericReturnArgument(PyObject *module);
#if QT_CONFIG(future)
PyTypeObject *init_QFutureInterfaceBase(PyObject *module);
#endif
PyTypeObject *init_QFileSystemWatcher(PyObject *module);
PyTypeObject *init_QFileSelector(PyObject *module);
PyTypeObject *init_QFileInfo(PyObject *module);
PyTypeObject *init_QFileDevice(PyObject *module);
PyTypeObject *init_QSaveFile(PyObject *module);
PyTypeObject *init_QFile(PyObject *module);
PyTypeObject *init_QTemporaryFile(PyObject *module);
PyTypeObject *init_QFactoryInterface(PyObject *module);
PyTypeObject *init_QEventLoop(PyObject *module);
PyTypeObject *init_QEvent(PyObject *module);
PyTypeObject *init_QTimerEvent(PyObject *module);
PyTypeObject *init_QElapsedTimer(PyObject *module);
PyTypeObject *init_QEasingCurve(PyObject *module);
PyTypeObject *init_QDynamicPropertyChangeEvent(PyObject *module);
PyTypeObject *init_QDirIterator(PyObject *module);
PyTypeObject *init_QDir(PyObject *module);
PyTypeObject *init_QDeadlineTimer(PyObject *module);
PyTypeObject *init_QDeadlineTimerStaticFields(PyObject *module);
#if QT_CONFIG(thread)
PyTypeObject *init_QWaitCondition(PyObject *module);
#endif
#if QT_CONFIG(thread)
PyTypeObject *init_QThread(PyObject *module);
#endif
#if QT_CONFIG(thread)
PyTypeObject *init_QRecursiveMutex(PyObject *module);
#endif
PyTypeObject *init_QReadWriteLock(PyObject *module);
PyTypeObject *init_QDateTime(PyObject *module);
#if QT_CONFIG(timezone)
PyTypeObject *init_QTimeZone_OffsetData(PyObject *enclosingClass);
#endif
PyTypeObject *init_QDate(PyObject *module);
PyTypeObject *init_QDataStream(PyObject *module);
PyTypeObject *init_QCryptographicHash(PyObject *module);
PyTypeObject *init_QCoreApplication(PyObject *module);
#if QT_CONFIG(permissions)
PyTypeObject *init_QContactsPermission(PyObject *module);
#endif
PyTypeObject *init_QCommandLineParser(PyObject *module);
PyTypeObject *init_QCommandLineOption(PyObject *module);
PyTypeObject *init_QCollatorSortKey(PyObject *module);
PyTypeObject *init_QCollator(PyObject *module);
PyTypeObject *init_QChildEvent(PyObject *module);
PyTypeObject *init_QCborStreamWriter(PyObject *module);
PyTypeObject *init_QCborStreamReader(PyObject *module);
PyTypeObject *init_QCborStringResultString(PyObject *module);
PyTypeObject *init_QCborMap(PyObject *module);
PyTypeObject *init_QCborError(PyObject *module);
PyTypeObject *init_QCborParserError(PyObject *module);
PyTypeObject *init_QCborArray(PyObject *module);
#if QT_CONFIG(permissions)
PyTypeObject *init_QCameraPermission(PyObject *module);
#endif
#if QT_CONFIG(permissions)
PyTypeObject *init_QCalendarPermission(PyObject *module);
#endif
PyTypeObject *init_QCalendar(PyObject *module);
PyTypeObject *init_QCalendar_YearMonthDay(PyObject *enclosingClass);
PyTypeObject *init_QCalendar_SystemId(PyObject *enclosingClass);
PyTypeObject *init_QByteArrayMatcher(PyObject *module);
PyTypeObject *init_QByteArray(PyObject *module);
PyTypeObject *init_QUrl(PyObject *module);
PyTypeObject *init_QCborValue(PyObject *module);
PyTypeObject *init_QCborStringResultByteArray(PyObject *module);
PyTypeObject *init_QByteArray_FromBase64Result(PyObject *enclosingClass);
PyTypeObject *init_QBuffer(PyObject *module);
#if QT_CONFIG(permissions)
PyTypeObject *init_QBluetoothPermission(PyObject *module);
#endif
PyTypeObject *init_QBitArray(PyObject *module);
PyTypeObject *init_QBasicTimer(PyObject *module);
#if QT_CONFIG(thread)
PyTypeObject *init_QBasicMutex(PyObject *module);
#endif
#if QT_CONFIG(thread)
PyTypeObject *init_QMutex(PyObject *module);
#endif
PyTypeObject *init_QAbstractNativeEventFilter(PyObject *module);
PyTypeObject *init_QAbstractItemModel(PyObject *module);
PyTypeObject *init_QConcatenateTablesProxyModel(PyObject *module);
PyTypeObject *init_QAbstractTableModel(PyObject *module);
PyTypeObject *init_QAbstractProxyModel(PyObject *module);
PyTypeObject *init_QTransposeProxyModel(PyObject *module);
PyTypeObject *init_QSortFilterProxyModel(PyObject *module);
PyTypeObject *init_QIdentityProxyModel(PyObject *module);
PyTypeObject *init_QAbstractListModel(PyObject *module);
PyTypeObject *init_QStringListModel(PyObject *module);
PyTypeObject *init_QAbstractEventDispatcher(PyObject *module);
PyTypeObject *init_QAbstractEventDispatcher_TimerInfo(PyObject *enclosingClass);
PyTypeObject *init_QAbstractAnimation(PyObject *module);
PyTypeObject *init_QVariantAnimation(PyObject *module);
PyTypeObject *init_QPropertyAnimation(PyObject *module);
PyTypeObject *init_QPauseAnimation(PyObject *module);
PyTypeObject *init_QAnimationGroup(PyObject *module);
PyTypeObject *init_QSequentialAnimationGroup(PyObject *module);
PyTypeObject *init_QParallelAnimationGroup(PyObject *module);

// Enum definitions ------------------------------------------------------------
static void QCborKnownTags_PythonToCpp_QCborKnownTags(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCborKnownTags>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCborKnownTags *>(cppOut) = value;

}
static PythonToCppFunc is_QCborKnownTags_PythonToCpp_QCborKnownTags_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborKnownTags_IDX])))
        return QCborKnownTags_PythonToCpp_QCborKnownTags;
    return {};
}
static PyObject *QCborKnownTags_CppToPython_QCborKnownTags(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCborKnownTags *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborKnownTags_IDX]), castCppIn);

}

static void QCborSimpleType_PythonToCpp_QCborSimpleType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCborSimpleType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCborSimpleType *>(cppOut) = value;

}
static PythonToCppFunc is_QCborSimpleType_PythonToCpp_QCborSimpleType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX])))
        return QCborSimpleType_PythonToCpp_QCborSimpleType;
    return {};
}
static PyObject *QCborSimpleType_CppToPython_QCborSimpleType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCborSimpleType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX]), castCppIn);

}

static void QCborTag_PythonToCpp_QCborTag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCborTag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCborTag *>(cppOut) = value;

}
static PythonToCppFunc is_QCborTag_PythonToCpp_QCborTag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborTag_IDX])))
        return QCborTag_PythonToCpp_QCborTag;
    return {};
}
static PyObject *QCborTag_CppToPython_QCborTag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCborTag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborTag_IDX]), castCppIn);

}

static void QtMsgType_PythonToCpp_QtMsgType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QtMsgType>(Shiboken::Enum::getValue(pyIn));
    switch (value) {
    case QtMsgType::QtSystemMsg:
        Shiboken::Warnings::warnDeprecatedEnumValue("QtMsgType", "QtSystemMsg");
        break;
    default:
        break;
    }
    *reinterpret_cast<::QtMsgType *>(cppOut) = value;

}
static PythonToCppFunc is_QtMsgType_PythonToCpp_QtMsgType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX])))
        return QtMsgType_PythonToCpp_QtMsgType;
    return {};
}
static PyObject *QtMsgType_CppToPython_QtMsgType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QtMsgType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX]), castCppIn);

}



// Module initialization ------------------------------------------------------------

// Primitive Type converters.

// C++ to Python conversion for primitive type 'QAnyStringView'.
static PyObject *QAnyStringView_CppToPython_QAnyStringView(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::QAnyStringView *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-pyunicode-from-qanystringview)]
    return PySide::qStringToPyUnicode(cppInRef.toString());
    // END of custom code block [file: ../glue/qtcore.cpp (return-pyunicode-from-qanystringview)]
    // ========================================================================

}
// C++ to Python conversion for primitive type 'QByteArrayView'.
static PyObject *QByteArrayView_CppToPython_QByteArrayView(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::QByteArrayView *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-pybytes)]
    return PyBytes_FromStringAndSize(cppInRef.constData(), cppInRef.size());
    // END of custom code block [file: ../glue/qtcore.cpp (return-pybytes)]
    // ========================================================================

}
// C++ to Python conversion for primitive type 'QChar'.
static PyObject *QChar_CppToPython_QChar(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::QChar *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-pyunicode-qchar)]
    auto c = wchar_t(cppInRef.unicode());
    return PyUnicode_FromWideChar(&c, 1);
    // END of custom code block [file: ../glue/qtcore.cpp (return-pyunicode-qchar)]
    // ========================================================================

}
// Python to C++ conversions for type 'QChar'.
static void PyString_PythonToCpp_QChar(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pystring-char)]
    char c;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<char>(), pyIn, &(c));
    *reinterpret_cast<::QChar *>(cppOut) = QChar(static_cast<unsigned short>(c));
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pystring-char)]
    // ========================================================================

}
static PythonToCppFunc is_PyString_PythonToCpp_QChar_Convertible(PyObject *pyIn)
{
    if (Shiboken::String::checkChar(pyIn))
        return PyString_PythonToCpp_QChar;
    return {};
}
static void PyLong_PythonToCpp_QChar(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pyint)]
    int i;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn, &(i));
    *reinterpret_cast<::QChar *>(cppOut) = QChar(i);
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pyint)]
    // ========================================================================

}
static PythonToCppFunc is_PyLong_PythonToCpp_QChar_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return PyLong_PythonToCpp_QChar;
    return {};
}
static void Py_None_PythonToCpp_QChar(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pynone)]
    SBK_UNUSED(pyIn)
    *reinterpret_cast<::QChar *>(cppOut) = QChar();
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pynone)]
    // ========================================================================

}
static PythonToCppFunc is_Py_None_PythonToCpp_QChar_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Py_None_PythonToCpp_QChar;
    return {};
}

// C++ to Python conversion for primitive type 'QFunctionPointer'.
static PyObject *QFunctionPointer_CppToPython_QFunctionPointer(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::QFunctionPointer *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-qfunctionpointer-pylong)]
    return PyLong_FromVoidPtr(reinterpret_cast<void *>(cppInRef));
    // END of custom code block [file: ../glue/qtcore.cpp (return-qfunctionpointer-pylong)]
    // ========================================================================

}
// Python to C++ conversions for type 'QFunctionPointer'.
static void PyLong_PythonToCpp_QFunctionPointer(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pylong-qfunctionpointer)]
    *reinterpret_cast<::QFunctionPointer *>(cppOut) = reinterpret_cast<QFunctionPointer>(PyLong_AsVoidPtr(pyIn));
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pylong-qfunctionpointer)]
    // ========================================================================

}
static PythonToCppFunc is_PyLong_PythonToCpp_QFunctionPointer_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return PyLong_PythonToCpp_QFunctionPointer;
    return {};
}

// C++ to Python conversion for primitive type 'QJsonObject'.
static PyObject *QJsonObject_CppToPython_QJsonObject(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::QJsonObject *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-qjsonobject)]
    // The QVariantMap returned by QJsonObject seems to cause a segfault, so
    // using QJsonObject.toVariantMap() won't work.
    // Wrapping it in a QJsonValue first allows it to work
    QJsonValue val(cppInRef);
    QVariant ret = val.toVariant();

    return Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &ret);
    // END of custom code block [file: ../glue/qtcore.cpp (return-qjsonobject)]
    // ========================================================================

}
// Python to C++ conversions for type 'QJsonObject'.
static void PyDict_PythonToCpp_QJsonObject(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-qjsonobject-pydict)]
    QVariant dict = QVariant_convertToVariantMap(pyIn);
    QJsonValue val = QJsonValue::fromVariant(dict);
    *reinterpret_cast<::QJsonObject *>(cppOut) = val.toObject();
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-qjsonobject-pydict)]
    // ========================================================================

}
static PythonToCppFunc is_PyDict_PythonToCpp_QJsonObject_Convertible(PyObject *pyIn)
{
    if (PyDict_Check(pyIn))
        return PyDict_PythonToCpp_QJsonObject;
    return {};
}

// C++ to Python conversion for primitive type 'QLatin1String'.
static PyObject *QLatin1String_CppToPython_QLatin1String(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::QLatin1String *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-pyunicode-from-qlatin1string)]
#ifdef Py_LIMITED_API
    return PySide::qStringToPyUnicode(QString::fromLatin1(cppInRef));
#else
    return PyUnicode_FromKindAndData(PyUnicode_1BYTE_KIND, cppInRef.constData(), cppInRef.size());
#endif
    // END of custom code block [file: ../glue/qtcore.cpp (return-pyunicode-from-qlatin1string)]
    // ========================================================================

}
// Python to C++ conversions for type 'QLatin1String'.
static void PyString_PythonToCpp_QLatin1String(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pystring-qlatin1string)]
    const char *data = reinterpret_cast<const char *>(_PepUnicode_DATA(pyIn));
    const Py_ssize_t len = PyUnicode_GetLength(pyIn);
    *reinterpret_cast<::QLatin1String *>(cppOut) = QLatin1String(data, len);
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pystring-qlatin1string)]
    // ========================================================================

}
static PythonToCppFunc is_PyString_PythonToCpp_QLatin1String_Convertible(PyObject *pyIn)
{
    if (qLatin1StringCheck(pyIn))
        return PyString_PythonToCpp_QLatin1String;
    return {};
}

// C++ to Python conversion for primitive type 'QString'.
static PyObject *QString_CppToPython_QString(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::QString *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-pyunicode)]
    return PySide::qStringToPyUnicode(cppInRef);
    // END of custom code block [file: ../glue/qtcore.cpp (return-pyunicode)]
    // ========================================================================

}
// Python to C++ conversions for type 'QString'.
static void PyUnicode_PythonToCpp_QString(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pyunicode)]
    *reinterpret_cast<::QString *>(cppOut) = PySide::pyUnicodeToQString(pyIn);
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pyunicode)]
    // ========================================================================

}
static PythonToCppFunc is_PyUnicode_PythonToCpp_QString_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return PyUnicode_PythonToCpp_QString;
    return {};
}
static void Py_None_PythonToCpp_QString(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pynone)]
    SBK_UNUSED(pyIn)
    *reinterpret_cast<::QString *>(cppOut) = QString();
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pynone)]
    // ========================================================================

}
static PythonToCppFunc is_Py_None_PythonToCpp_QString_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Py_None_PythonToCpp_QString;
    return {};
}

// C++ to Python conversion for primitive type 'QStringList'.
static PyObject *QStringList_CppToPython_QStringList(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::QStringList *>(const_cast<void *>(cppIn));
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
// Python to C++ conversions for type 'QStringList'.
static void PySequence_PythonToCpp_QStringList(PyObject *pyIn, void *cppOut)
{
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (*reinterpret_cast<::QStringList *>(cppOut)).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (*reinterpret_cast<::QStringList *>(cppOut)).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QString cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyItem, &(cppItem));
        (*reinterpret_cast<::QStringList *>(cppOut)).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QStringList_Convertible(PyObject *pyIn)
{
    if (Shiboken::String::checkIterable(pyIn))
        return PySequence_PythonToCpp_QStringList;
    return {};
}

// C++ to Python conversion for primitive type 'QStringView'.
static PyObject *QStringView_CppToPython_QStringView(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::QStringView *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-pyunicode)]
    return PySide::qStringToPyUnicode(cppInRef);
    // END of custom code block [file: ../glue/qtcore.cpp (return-pyunicode)]
    // ========================================================================

}
// C++ to Python conversion for primitive type 'QVariant'.
static PyObject *QVariant_CppToPython_QVariant(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::QVariant *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-qvariant)]
    if (!cppInRef.isValid())
        Py_RETURN_NONE;

    switch (cppInRef.typeId()) {
    case QMetaType::UnknownType:
    case QMetaType::Nullptr:
        Py_RETURN_NONE;
    case QMetaType::VoidStar:
        if (cppInRef.constData() == nullptr)
            Py_RETURN_NONE;
        break;

    case QMetaType::QVariantList: {
        const auto var = cppInRef.value<QVariantList>();
        return Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QVariant_IDX], &var);
    }
    case QMetaType::QStringList: {
        const auto var = cppInRef.value<QStringList>();
        return Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QString_IDX], &var);
    }
    case QMetaType::QVariantMap: {
        const auto var = cppInRef.value<QVariantMap>();
        return Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QMap_QString_QVariant_IDX], &var);
    }
    default:
        break;
    }

    auto converterO = converterForQtType(cppInRef.typeName());
    if (converterO.has_value())
        return converterO.value().toPython(cppInRef.data());

    PyErr_Format(PyExc_RuntimeError, "Can't find converter for '%s'.", cppInRef.typeName());
    return 0;
    // END of custom code block [file: ../glue/qtcore.cpp (return-qvariant)]
    // ========================================================================

}
// Python to C++ conversions for type 'QVariant'.
static void PyBool_PythonToCpp_QVariant(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pybool)]
    *reinterpret_cast<::QVariant *>(cppOut) = QVariant(pyIn == Py_True);
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pybool)]
    // ========================================================================

}
static PythonToCppFunc is_PyBool_PythonToCpp_QVariant_Convertible(PyObject *pyIn)
{
    if (PyBool_Check(pyIn))
        return PyBool_PythonToCpp_QVariant;
    return {};
}
static void Py_None_PythonToCpp_QVariant(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pynone)]
    SBK_UNUSED(pyIn)
    *reinterpret_cast<::QVariant *>(cppOut) = QVariant();
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pynone)]
    // ========================================================================

}
static PythonToCppFunc is_Py_None_PythonToCpp_QVariant_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Py_None_PythonToCpp_QVariant;
    return {};
}
static void QString_PythonToCpp_QVariant(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-qstring)]
    ::QString in;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &(in));
    *reinterpret_cast<::QVariant *>(cppOut) = QVariant(in);
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-qstring)]
    // ========================================================================

}
static PythonToCppFunc is_QString_PythonToCpp_QVariant_Convertible(PyObject *pyIn)
{
    if (Shiboken::String::check(pyIn))
        return QString_PythonToCpp_QVariant;
    return {};
}
static void QByteArray_PythonToCpp_QVariant(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-qbytearray)]
    ::QByteArray in;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyIn, &(in));
    *reinterpret_cast<::QVariant *>(cppOut) = QVariant(in);
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-qbytearray)]
    // ========================================================================

}
static PythonToCppFunc is_QByteArray_PythonToCpp_QVariant_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))
        return QByteArray_PythonToCpp_QVariant;
    return {};
}
static void PyFloat_PythonToCpp_QVariant(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pyfloat)]
    double in;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<double>(), pyIn, &(in));
    *reinterpret_cast<::QVariant *>(cppOut) = QVariant(in);
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pyfloat)]
    // ========================================================================

}
static PythonToCppFunc is_PyFloat_PythonToCpp_QVariant_Convertible(PyObject *pyIn)
{
    if (PyFloat_CheckExact(pyIn))
        return PyFloat_PythonToCpp_QVariant;
    return {};
}
static void PyLong_PythonToCpp_QVariant(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-qlonglong)]
    // PYSIDE-1250: For QVariant, if the type fits into an int; use int preferably.
    qlonglong in;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qlonglong>(), pyIn, &(in));
    constexpr qlonglong intMax = qint64(std::numeric_limits<int>::max());
    constexpr qlonglong intMin = qint64(std::numeric_limits<int>::min());
    *reinterpret_cast<::QVariant *>(cppOut) = in >= intMin && in <= intMax ? QVariant(int(in)) : QVariant(in);
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-qlonglong)]
    // ========================================================================

}
static PythonToCppFunc is_PyLong_PythonToCpp_QVariant_Convertible(PyObject *pyIn)
{
    if (PyLong_CheckExact(pyIn))
        return PyLong_PythonToCpp_QVariant;
    return {};
}
static void SbkObject_PythonToCpp_QVariant(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-sbkobject)]
    // a class supported by QVariant?
    const QMetaType metaType = QVariant_resolveMetaType(Py_TYPE(pyIn));
    bool ok = false;
    if (metaType.isValid()) {
        QVariant var(metaType);
        auto converterO = converterForQtType(metaType.name());
        ok = converterO.has_value();
        if (ok) {
            converterO.value().toCpp(pyIn, var.data());
            *reinterpret_cast<::QVariant *>(cppOut) = var;
        } else {
            qWarning("%s: Cannot find a converter for \"%s\".",
                     __FUNCTION__, metaType.name());
        }
    }

    // If the type was not encountered, return a default PyObjectWrapper
    if (!ok)
        *reinterpret_cast<::QVariant *>(cppOut) = QVariant::fromValue(PySide::PyObjectWrapper(pyIn));
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-sbkobject)]
    // ========================================================================

}
static PythonToCppFunc is_SbkObject_PythonToCpp_QVariant_Convertible(PyObject *pyIn)
{
    if (Shiboken::Object::checkType(pyIn))
        return SbkObject_PythonToCpp_QVariant;
    return {};
}
static void PyDict_PythonToCpp_QVariant(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pydict)]
    QVariant ret = QVariant_convertToVariantMap(pyIn);
    *reinterpret_cast<::QVariant *>(cppOut) = ret.isValid() ? ret : QVariant::fromValue(PySide::PyObjectWrapper(pyIn));
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pydict)]
    // ========================================================================

}
static PythonToCppFunc is_PyDict_PythonToCpp_QVariant_Convertible(PyObject *pyIn)
{
    if (PyDict_CheckExact(pyIn))
        return PyDict_PythonToCpp_QVariant;
    return {};
}
static void PyList_PythonToCpp_QVariant(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pylist)]
    QVariant ret = QVariant_convertToVariantList(pyIn);
    *reinterpret_cast<::QVariant *>(cppOut) = ret.isValid() ? ret : QVariant::fromValue(PySide::PyObjectWrapper(pyIn));
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pylist)]
    // ========================================================================

}
static PythonToCppFunc is_PyList_PythonToCpp_QVariant_Convertible(PyObject *pyIn)
{
    if (PyList_Check(pyIn))
        return PyList_PythonToCpp_QVariant;
    return {};
}
static void PyObject_PythonToCpp_QVariant(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pyobject)]
    // Is a shiboken type not known by Qt
    *reinterpret_cast<::QVariant *>(cppOut) = QVariant::fromValue(PySide::PyObjectWrapper(pyIn));
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pyobject)]
    // ========================================================================

}
static PythonToCppFunc is_PyObject_PythonToCpp_QVariant_Convertible(PyObject *pyIn)
{
    SBK_UNUSED(pyIn)
    if (true)
        return PyObject_PythonToCpp_QVariant;
    return {};
}

// C++ to Python conversion for primitive type 'qintptr'.
static PyObject *qintptr_CppToPython_qintptr(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::qintptr *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-pylong)]
    return PyLong_FromLong(cppInRef);
    // END of custom code block [file: ../glue/qtcore.cpp (return-pylong)]
    // ========================================================================

}
// Python to C++ conversions for type 'qintptr'.
static void PyLong_PythonToCpp_qintptr(PyObject *pyIn, void *cppOut)
{
    // TEMPLATE - shiboken_conversion_pylong_to_cpp - START
    *reinterpret_cast<::qintptr *>(cppOut) = qintptr(PyLong_AsLong(pyIn));
    // TEMPLATE - shiboken_conversion_pylong_to_cpp - END

}
static PythonToCppFunc is_PyLong_PythonToCpp_qintptr_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return PyLong_PythonToCpp_qintptr;
    return {};
}

// C++ to Python conversion for primitive type 'qptrdiff'.
static PyObject *qptrdiff_CppToPython_qptrdiff(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::qptrdiff *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-pylong)]
    return PyLong_FromLong(cppInRef);
    // END of custom code block [file: ../glue/qtcore.cpp (return-pylong)]
    // ========================================================================

}
// Python to C++ conversions for type 'qptrdiff'.
static void PyLong_PythonToCpp_qptrdiff(PyObject *pyIn, void *cppOut)
{
    // TEMPLATE - shiboken_conversion_pylong_to_cpp - START
    *reinterpret_cast<::qptrdiff *>(cppOut) = qptrdiff(PyLong_AsLong(pyIn));
    // TEMPLATE - shiboken_conversion_pylong_to_cpp - END

}
static PythonToCppFunc is_PyLong_PythonToCpp_qptrdiff_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return PyLong_PythonToCpp_qptrdiff;
    return {};
}

// C++ to Python conversion for primitive type 'quintptr'.
static PyObject *quintptr_CppToPython_quintptr(const void *cppIn)
{
    auto &cppInRef = *reinterpret_cast<::quintptr *>(const_cast<void *>(cppIn));
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-pylong-quintptr)]
#if QT_POINTER_SIZE == 8
    return PyLong_FromUnsignedLongLong(cppInRef);
#else
    return PyLong_FromUnsignedLong(cppInRef);
#endif
    // END of custom code block [file: ../glue/qtcore.cpp (return-pylong-quintptr)]
    // ========================================================================

}
// Python to C++ conversions for type 'quintptr'.
static void PyLong_PythonToCpp_quintptr(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pylong-quintptr)]
#if QT_POINTER_SIZE == 8
    *reinterpret_cast<::quintptr *>(cppOut) = quintptr(PyLong_AsUnsignedLongLong(pyIn));
#else
    *reinterpret_cast<::quintptr *>(cppOut) = quintptr(PyLong_AsUnsignedLong(pyIn));
#endif
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pylong-quintptr)]
    // ========================================================================

}
static PythonToCppFunc is_PyLong_PythonToCpp_quintptr_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return PyLong_PythonToCpp_quintptr;
    return {};
}


// Container Type converters.

// C++ to Python conversion for container type 'QList<int>'.
static PyObject *QList_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn))
        return PySequence_PythonToCpp_QList_int_;
    return {};
}


// Binding for QList<int>

template <>
struct ShibokenContainerValueConverter<int>
{
    static bool checkValue(PyObject *pyArg)
    {
        return PyLong_Check(pyArg);
    }

    static PyObject *convertValueToPython(int cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg);
    }

    static std::optional<int> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!(PyLong_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        int cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QIntList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QIntList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QIntList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QIntList_spec = {
    "2:PySide6.QtCore.QIntList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QIntList_slots
};

static inline PyTypeObject *createQIntListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QIntList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QIntList_TypeF()
{
    static PyTypeObject *type = createQIntListType();
    return type;
}

extern "C" PyObject *createQIntList(QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQIntList(const QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = const_cast<QList<int> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QIntList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QIntList_TypeF();
}

extern "C" void PythonToCppQIntList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<int>>::get(pyArg);
    *reinterpret_cast<QList<int>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQIntListPythonToCppConvertible(PyObject *pyArg)
{
    if (QIntList_Check(pyArg))
        return PythonToCppQIntList;
    return {};
}

// C++ to Python conversion for container type 'QList<QPoint>'.
static PyObject *QList_QPoint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPoint> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QPoint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPoint> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPoint cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QPoint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QPoint_;
    return {};
}


// Binding for QList<QPoint>

template <>
struct ShibokenContainerValueConverter<QPoint>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), pyArg);
    }

    static PyObject *convertValueToPython(const QPoint &cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppArg);
    }

    static std::optional<QPoint> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QPoint cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QPointList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QPointList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QPointList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QPointList_spec = {
    "2:PySide6.QtCore.QPointList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QPointList_slots
};

static inline PyTypeObject *createQPointListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QPointList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QPointList_TypeF()
{
    static PyTypeObject *type = createQPointListType();
    return type;
}

extern "C" PyObject *createQPointList(QList<QPoint>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPoint>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQPointList(const QList<QPoint>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPoint>>();
    d->m_list = const_cast<QList<QPoint> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QPointList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QPointList_TypeF();
}

extern "C" void PythonToCppQPointList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QPoint>>::get(pyArg);
    *reinterpret_cast<QList<QPoint>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQPointListPythonToCppConvertible(PyObject *pyArg)
{
    if (QPointList_Check(pyArg))
        return PythonToCppQPointList;
    return {};
}

// C++ to Python conversion for container type 'QList<QPointF>'.
static PyObject *QList_QPointF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPointF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QPointF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPointF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPointF cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QPointF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QPointF_;
    return {};
}


// Binding for QList<QPointF>

template <>
struct ShibokenContainerValueConverter<QPointF>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), pyArg);
    }

    static PyObject *convertValueToPython(const QPointF &cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppArg);
    }

    static std::optional<QPointF> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QPointF cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QPointFList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QPointFList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QPointFList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QPointFList_spec = {
    "2:PySide6.QtCore.QPointFList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QPointFList_slots
};

static inline PyTypeObject *createQPointFListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QPointFList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QPointFList_TypeF()
{
    static PyTypeObject *type = createQPointFListType();
    return type;
}

extern "C" PyObject *createQPointFList(QList<QPointF>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointFList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPointF>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQPointFList(const QList<QPointF>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointFList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPointF>>();
    d->m_list = const_cast<QList<QPointF> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QPointFList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QPointFList_TypeF();
}

extern "C" void PythonToCppQPointFList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QPointF>>::get(pyArg);
    *reinterpret_cast<QList<QPointF>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQPointFListPythonToCppConvertible(PyObject *pyArg)
{
    if (QPointFList_Check(pyArg))
        return PythonToCppQPointFList;
    return {};
}

// C++ to Python conversion for container type 'QList<QObject*>'.
static PyObject *QList_QObjectPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QObject*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QObjectPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QObject*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QObject* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QObjectPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QObjectPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QByteArray>'.
static PyObject *QList_QByteArray__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QByteArray cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QXmlStreamNamespaceDeclaration>'.
static PyObject *QList_QXmlStreamNamespaceDeclaration__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QXmlStreamNamespaceDeclaration> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamNamespaceDeclaration_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QXmlStreamNamespaceDeclaration_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QXmlStreamNamespaceDeclaration> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QXmlStreamNamespaceDeclaration cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamNamespaceDeclaration_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QXmlStreamNamespaceDeclaration__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamNamespaceDeclaration_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QXmlStreamNamespaceDeclaration_;
    return {};
}

// C++ to Python conversion for container type 'QList<QXmlStreamEntityDeclaration>'.
static PyObject *QList_QXmlStreamEntityDeclaration__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QXmlStreamEntityDeclaration> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityDeclaration_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QXmlStreamEntityDeclaration_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QXmlStreamEntityDeclaration> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QXmlStreamEntityDeclaration cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityDeclaration_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QXmlStreamEntityDeclaration__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityDeclaration_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QXmlStreamEntityDeclaration_;
    return {};
}

// C++ to Python conversion for container type 'QList<QXmlStreamNotationDeclaration>'.
static PyObject *QList_QXmlStreamNotationDeclaration__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QXmlStreamNotationDeclaration> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamNotationDeclaration_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QXmlStreamNotationDeclaration_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QXmlStreamNotationDeclaration> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QXmlStreamNotationDeclaration cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamNotationDeclaration_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QXmlStreamNotationDeclaration__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamNotationDeclaration_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QXmlStreamNotationDeclaration_;
    return {};
}

// C++ to Python conversion for container type 'QList<QXmlStreamAttribute>'.
static PyObject *QList_QXmlStreamAttribute__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QXmlStreamAttribute> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QXmlStreamAttribute_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QXmlStreamAttribute> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QXmlStreamAttribute cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QXmlStreamAttribute__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamAttribute_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QXmlStreamAttribute_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<QString,QString>'.
static PyObject *std_pair_QString_QString__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<QString,QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_QString_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<QString,QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_QString_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, pyIn))
        return PySequence_PythonToCpp_std_pair_QString_QString_;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair< QString,QString>>'.
static PyObject *QList_std_pair_QString_QString___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair< QString,QString>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_QString_QString_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_std_pair_QString_QString__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair< QString,QString>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::std::pair<QString,QString> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_QString_QString_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_std_pair_QString_QString___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_QString_QString_IDX], pyIn))
        return PySequence_PythonToCpp_QList_std_pair_QString_QString__;
    return {};
}

// C++ to Python conversion for container type 'QList<QStorageInfo>'.
static PyObject *QList_QStorageInfo__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QStorageInfo> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QStorageInfo_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QStorageInfo> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QStorageInfo cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QStorageInfo__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStorageInfo_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QStorageInfo_;
    return {};
}

// C++ to Python conversion for container type 'QList<QMimeType>'.
static PyObject *QList_QMimeType__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QMimeType> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QMimeType_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QMimeType> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QMimeType cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QMimeType__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QMimeType_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLocale::Country>'.
static PyObject *QList_QLocale_Country__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLocale::Country> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QLocale_Country_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLocale::Country> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLocale::Country cppItem{QLocale::AnyCountry};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QLocale_Country__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, pyIn))
        return PySequence_PythonToCpp_QList_QLocale_Country_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLocale>'.
static PyObject *QList_QLocale__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLocale> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QLocale_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLocale> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLocale cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QLocale__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QLocale_;
    return {};
}

// C++ to Python conversion for container type 'QList<Qt::DayOfWeek>'.
static PyObject *QList_Qt_DayOfWeek__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<Qt::DayOfWeek> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DayOfWeek_IDX])))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_Qt_DayOfWeek_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<Qt::DayOfWeek> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::Qt::DayOfWeek cppItem = static_cast< ::Qt::DayOfWeek>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DayOfWeek_IDX])))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_Qt_DayOfWeek__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DayOfWeek_IDX])))->converter, pyIn))
        return PySequence_PythonToCpp_QList_Qt_DayOfWeek_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTimeZone::OffsetData>'.
static PyObject *QList_QTimeZone_OffsetData__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTimeZone::OffsetData> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_OffsetData_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QTimeZone_OffsetData_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTimeZone::OffsetData> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTimeZone::OffsetData cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_OffsetData_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QTimeZone_OffsetData__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_OffsetData_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QTimeZone_OffsetData_;
    return {};
}

// C++ to Python conversion for container type 'QList<QVariant>'.
static PyObject *QList_QVariant__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVariant cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyIn))
        return PySequence_PythonToCpp_QList_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QModelIndex>'.
static PyObject *QList_QModelIndex__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QModelIndex> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QModelIndex_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QModelIndex> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QModelIndex cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QModelIndex__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QModelIndex_;
    return {};
}

// C++ to Python conversion for container type 'QList<QItemSelectionRange>'.
static PyObject *QList_QItemSelectionRange__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QItemSelectionRange> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QItemSelectionRange_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QItemSelectionRange> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QItemSelectionRange cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QItemSelectionRange__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionRange_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QItemSelectionRange_;
    return {};
}

// C++ to Python conversion for container type 'QList<QUrl>'.
static PyObject *QList_QUrl__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QUrl> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QUrl_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QUrl> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QUrl cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QUrl__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QUrl_;
    return {};
}

// C++ to Python conversion for container type 'QList<QFileInfo>'.
static PyObject *QList_QFileInfo__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QFileInfo> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QFileInfo_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QFileInfo> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QFileInfo cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QFileInfo__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QFileInfo_;
    return {};
}

// C++ to Python conversion for container type 'QList<QCommandLineOption>'.
static PyObject *QList_QCommandLineOption__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QCommandLineOption> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QCommandLineOption_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QCommandLineOption> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QCommandLineOption* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(*cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QCommandLineOption__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QCommandLineOption_;
    return {};
}

// C++ to Python conversion for container type 'QHash<QString,QVariant>'.
static PyObject *QHash_QString_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QHash<QString,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp_QHash_QString_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QHash<QString,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp_QHash_QString_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp_QHash_QString_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QString,QVariant>'.
static PyObject *QMap_QString_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QString,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp_QMap_QString_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QString,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp_QMap_QString_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp_QMap_QString_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QCborValue>'.
static PyObject *QList_QCborValue__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QCborValue> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QCborValue_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QCborValue> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QCborValue cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QCborValue__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborValue_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QCborValue_;
    return {};
}

// C++ to Python conversion for container type 'QMap<int,QVariant>'.
static PyObject *QMap_int_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<int,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp_QMap_int_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<int,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp_QMap_int_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp_QMap_int_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QPersistentModelIndex>'.
static PyObject *QList_QPersistentModelIndex__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPersistentModelIndex> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QPersistentModelIndex_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPersistentModelIndex> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPersistentModelIndex cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QPersistentModelIndex__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPersistentModelIndex_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QPersistentModelIndex_;
    return {};
}

// C++ to Python conversion for container type 'QHash<int,QByteArray>'.
static PyObject *QHash_int_QByteArray__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QHash<int,QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp_QHash_int_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QHash<int,QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), key, &(cppKey));
        ::QByteArray cppValue;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp_QHash_int_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))->converter, false, pyIn))
        return PyDict_PythonToCpp_QHash_int_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QAbstractItemModel*>'.
static PyObject *QList_QAbstractItemModelPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QAbstractItemModel*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QAbstractItemModelPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QAbstractItemModel*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QAbstractItemModel* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QAbstractItemModelPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QAbstractItemModelPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QAbstractEventDispatcher::TimerInfo>'.
static PyObject *QList_QAbstractEventDispatcher_TimerInfo__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QAbstractEventDispatcher::TimerInfo> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractEventDispatcher_TimerInfo_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QAbstractEventDispatcher_TimerInfo_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QAbstractEventDispatcher::TimerInfo> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QAbstractEventDispatcher::TimerInfo cppItem = ::QAbstractEventDispatcher::TimerInfo(int(0), int(0), Qt::PreciseTimer);
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractEventDispatcher_TimerInfo_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QAbstractEventDispatcher_TimerInfo__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractEventDispatcher_TimerInfo_IDX]), pyIn))
        return PySequence_PythonToCpp_QList_QAbstractEventDispatcher_TimerInfo_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<double,QVariant>'.
static PyObject *std_pair_double_QVariant__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::std::pair<double,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SET_ITEM(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppInRef.first));
    PyTuple_SET_ITEM(pyOut, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_double_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::std::pair<double,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<double>(), PySequence_Fast_GET_ITEM(pyIn, 0), &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], PySequence_Fast_GET_ITEM(pyIn, 1), &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_double_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(Shiboken::Conversions::PrimitiveTypeConverter<double>(), false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PySequence_PythonToCpp_std_pair_double_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair< double,QVariant>>'.
static PyObject *QList_std_pair_double_QVariant___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair< double,QVariant>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_double_QVariant_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_std_pair_double_QVariant__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair< double,QVariant>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::std::pair<double,QVariant> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_double_QVariant_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_std_pair_double_QVariant___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_double_QVariant_IDX], pyIn))
        return PySequence_PythonToCpp_QList_std_pair_double_QVariant__;
    return {};
}

// C++ to Python conversion for container type 'QList<QString>'.
static PyObject *QList_QString__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp_QList_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QString cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_QList_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn))
        return PySequence_PythonToCpp_QList_QString_;
    return {};
}


static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtCore",
    /* m_doc      */ nullptr,
    /* m_size     */ -1,
    /* m_methods  */ QtCore_methods,
    /* m_reload   */ nullptr,
    /* m_traverse */ nullptr,
    /* m_clear    */ nullptr,
    /* m_free     */ nullptr
};

// The signatures string for the global functions.
// Multiple signatures have their index "n:" in front.
static const char *QtCore_SignatureStrings[] = {
    "PySide6.QtCore.QEnum(arg__1:PyObject)->PyObject",
    "PySide6.QtCore.QFlag(arg__1:PyObject)->PyObject",
    "PySide6.QtCore.QT_TRANSLATE_NOOP(arg__1:PyObject,arg__2:PyObject)->PyObject",
    "PySide6.QtCore.QT_TRANSLATE_NOOP3(arg__1:PyObject,arg__2:PyObject,arg__3:PyObject)->PyObject",
    "PySide6.QtCore.QT_TRANSLATE_NOOP_UTF8(arg__1:PyObject)->PyObject",
    "PySide6.QtCore.QT_TR_NOOP(arg__1:PyObject)->PyObject",
    "PySide6.QtCore.QT_TR_NOOP_UTF8(arg__1:PyObject)->PyObject",
    "PySide6.QtCore.Q_ARG(type:PyObject,value:PyObject)->PySide6.QtCore.QGenericArgumentHolder",
    "PySide6.QtCore.Q_RETURN_ARG(type:PyObject)->PySide6.QtCore.QGenericReturnArgumentHolder",
    "PySide6.QtCore.SIGNAL(arg__1:str)->str",
    "PySide6.QtCore.SLOT(arg__1:str)->str",
    "PySide6.QtCore.__init_feature__()",
    "PySide6.QtCore.__moduleShutdown()",
    "PySide6.QtCore.qAbs(arg__1:double)->double",
    "PySide6.QtCore.qAddPostRoutine(arg__1:PyObject)",
    "PySide6.QtCore.qCCritical(arg__1:PyObject,arg__2:char*)",
    "PySide6.QtCore.qCDebug(arg__1:PyObject,arg__2:char*)",
    "PySide6.QtCore.qCInfo(arg__1:PyObject,arg__2:char*)",
    "PySide6.QtCore.qCWarning(arg__1:PyObject,arg__2:char*)",
    "1:PySide6.QtCore.qCompress(data:PyBuffer,nbytes:qsizetype,compressionLevel:int=-1)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtCore.qCompress(data:typing.Union[PySide6.QtCore.QByteArray, char*],compressionLevel:int=-1)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.qCritical(arg__1:str)",
    "PySide6.QtCore.qDebug(arg__1:str)",
    "PySide6.QtCore.qFastCos(x:qreal)->qreal",
    "PySide6.QtCore.qFastSin(x:qreal)->qreal",
    "PySide6.QtCore.qFatal(arg__1:str)",
    "PySide6.QtCore.qFormatLogMessage(type:PySide6.QtCore.QtMsgType,context:PySide6.QtCore.QMessageLogContext,buf:QString)->QString",
    "PySide6.QtCore.qFuzzyCompare(p1:double,p2:double)->bool",
    "PySide6.QtCore.qFuzzyIsNull(d:double)->bool",
    "PySide6.QtCore.qInstallMessageHandler(arg__1:PyObject)->PyObject",
    "PySide6.QtCore.qIsFinite(d:double)->bool",
    "PySide6.QtCore.qIsInf(d:double)->bool",
    "PySide6.QtCore.qIsNaN(d:double)->bool",
    "PySide6.QtCore.qIsNull(d:double)->bool",
    "PySide6.QtCore.qRegisterResourceData(arg__1:int,arg__2:PyBytes,arg__3:PyBytes,arg__4:PyBytes)->bool",
    "PySide6.QtCore.qSetMessagePattern(messagePattern:QString)",
    "1:PySide6.QtCore.qUncompress(data:PyBuffer,nbytes:qsizetype)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtCore.qUncompress(data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.qUnregisterResourceData(arg__1:int,arg__2:PyBytes,arg__3:PyBytes,arg__4:PyBytes)->bool",
    "PySide6.QtCore.qVersion()->str",
    "PySide6.QtCore.qWarning(arg__1:str)",
    "PySide6.QtCore.qtTrId(id:char*,n:int=-1)->QString",
    nullptr}; // Sentinel

extern "C" LIBSHIBOKEN_EXPORT PyObject *PyInit_QtCore()
{
    if (SbkPySide6_QtCoreModuleObject != nullptr)
        return SbkPySide6_QtCoreModuleObject;
    // Create an array of wrapper types/names for the current module.
    static Shiboken::Module::TypeInitStruct cppApi[] = {
        {nullptr, "PySide6.QtCore.QAbstractAnimation"},
        {nullptr, "PySide6.QtCore.QAbstractAnimation.DeletionPolicy"},
        {nullptr, "PySide6.QtCore.QAbstractAnimation.Direction"},
        {nullptr, "PySide6.QtCore.QAbstractAnimation.State"},
        {nullptr, "PySide6.QtCore.QAbstractEventDispatcher"},
        {nullptr, "PySide6.QtCore.QAbstractEventDispatcher.TimerInfo"},
        {nullptr, "PySide6.QtCore.QAbstractItemModel"},
        {nullptr, "PySide6.QtCore.QAbstractItemModel.CheckIndexOption"},
        {nullptr, "PySide6.QtCore.QAbstractItemModel.LayoutChangeHint"},
        {nullptr, "PySide6.QtCore.QAbstractListModel"},
        {nullptr, "PySide6.QtCore.QAbstractNativeEventFilter"},
        {nullptr, "PySide6.QtCore.QAbstractProxyModel"},
        {nullptr, "PySide6.QtCore.QAbstractTableModel"},
        {nullptr, "PySide6.QtCore.QAnimationGroup"},
        {nullptr, "PySide6.QtCore.QBasicMutex"},
        {nullptr, "PySide6.QtCore.QBasicTimer"},
        {nullptr, "PySide6.QtCore.QBitArray"},
        {nullptr, "PySide6.QtCore.QBluetoothPermission"},
        {nullptr, "PySide6.QtCore.QBluetoothPermission.CommunicationMode"},
        {nullptr, "PySide6.QtCore.QBuffer"},
        {nullptr, "PySide6.QtCore.QByteArray"},
        {nullptr, "PySide6.QtCore.QByteArray.Base64DecodingStatus"},
        {nullptr, "PySide6.QtCore.QByteArray.Base64Option"},
        {nullptr, "PySide6.QtCore.QByteArray.FromBase64Result"},
        {nullptr, "PySide6.QtCore.QByteArrayMatcher"},
        {nullptr, "PySide6.QtCore.QCalendar"},
        {nullptr, "PySide6.QtCore.QCalendar.System"},
        {nullptr, "PySide6.QtCore.QCalendar.SystemId"},
        {nullptr, "PySide6.QtCore.QCalendar.Unspecified"},
        {nullptr, "PySide6.QtCore.QCalendar.YearMonthDay"},
        {nullptr, "PySide6.QtCore.QCalendarPermission"},
        {nullptr, "PySide6.QtCore.QCalendarPermission.AccessMode"},
        {nullptr, "PySide6.QtCore.QCameraPermission"},
        {nullptr, "PySide6.QtCore.QCborArray"},
        {nullptr, "PySide6.QtCore.QCborError"},
        {nullptr, "PySide6.QtCore.QCborError.Code"},
        {nullptr, "PySide6.QtCore.QCborKnownTags"},
        {nullptr, "PySide6.QtCore.QCborMap"},
        {nullptr, "PySide6.QtCore.QCborParserError"},
        {nullptr, "PySide6.QtCore.QCborSimpleType"},
        {nullptr, "PySide6.QtCore.QCborStreamReader"},
        {nullptr, "PySide6.QtCore.QCborStreamReader.StringResultCode"},
        {nullptr, "PySide6.QtCore.QCborStreamReader.Type"},
        {nullptr, "PySide6.QtCore.QCborStreamWriter"},
        {nullptr, "PySide6.QtCore.QCborStringResultByteArray"},
        {nullptr, "PySide6.QtCore.QCborStringResultString"},
        {nullptr, "PySide6.QtCore.QCborTag"},
        {nullptr, "PySide6.QtCore.QCborValue"},
        {nullptr, "PySide6.QtCore.QCborValue.DiagnosticNotationOption"},
        {nullptr, "PySide6.QtCore.QCborValue.EncodingOption"},
        {nullptr, "PySide6.QtCore.QCborValue.Type"},
        {nullptr, "PySide6.QtCore.QChildEvent"},
        {nullptr, "PySide6.QtCore.QCollator"},
        {nullptr, "PySide6.QtCore.QCollatorSortKey"},
        {nullptr, "PySide6.QtCore.QCommandLineOption"},
        {nullptr, "PySide6.QtCore.QCommandLineOption.Flag"},
        {nullptr, "PySide6.QtCore.QCommandLineParser"},
        {nullptr, "PySide6.QtCore.QCommandLineParser.OptionsAfterPositionalArgumentsMode"},
        {nullptr, "PySide6.QtCore.QCommandLineParser.SingleDashWordOptionMode"},
        {nullptr, "PySide6.QtCore.QConcatenateTablesProxyModel"},
        {nullptr, "PySide6.QtCore.QContactsPermission"},
        {nullptr, "PySide6.QtCore.QContactsPermission.AccessMode"},
        {nullptr, "PySide6.QtCore.QCoreApplication"},
        {nullptr, "PySide6.QtCore.QCryptographicHash"},
        {nullptr, "PySide6.QtCore.QCryptographicHash.Algorithm"},
        {nullptr, "PySide6.QtCore.QDataStream"},
        {nullptr, "PySide6.QtCore.QDataStream.ByteOrder"},
        {nullptr, "PySide6.QtCore.QDataStream.FloatingPointPrecision"},
        {nullptr, "PySide6.QtCore.QDataStream.Status"},
        {nullptr, "PySide6.QtCore.QDataStream.Version"},
        {nullptr, "PySide6.QtCore.QDate"},
        {nullptr, "PySide6.QtCore.QDateTime"},
        {nullptr, "PySide6.QtCore.QDateTime.TransitionResolution"},
        {nullptr, "PySide6.QtCore.QDateTime.YearRange"},
        {nullptr, "PySide6.QtCore.QDeadlineTimer"},
        {nullptr, "PySide6.QtCore.QDeadlineTimer.ForeverConstant"},
        {nullptr, "PySide6.QtCore.QDir"},
        {nullptr, "PySide6.QtCore.QDir.Filter"},
        {nullptr, "PySide6.QtCore.QDir.SortFlag"},
        {nullptr, "PySide6.QtCore.QDirIterator"},
        {nullptr, "PySide6.QtCore.QDirIterator.IteratorFlag"},
        {nullptr, "PySide6.QtCore.QDynamicPropertyChangeEvent"},
        {nullptr, "PySide6.QtCore.QEasingCurve"},
        {nullptr, "PySide6.QtCore.QEasingCurve.Type"},
        {nullptr, "PySide6.QtCore.QElapsedTimer"},
        {nullptr, "PySide6.QtCore.QElapsedTimer.ClockType"},
        {nullptr, "PySide6.QtCore.QEvent"},
        {nullptr, "PySide6.QtCore.QEvent.Type"},
        {nullptr, "PySide6.QtCore.QEventLoop"},
        {nullptr, "PySide6.QtCore.QEventLoop.ProcessEventsFlag"},
        {nullptr, "PySide6.QtCore.QFactoryInterface"},
        {nullptr, "PySide6.QtCore.QFile"},
        {nullptr, "PySide6.QtCore.QFileDevice"},
        {nullptr, "PySide6.QtCore.QFileDevice.FileError"},
        {nullptr, "PySide6.QtCore.QFileDevice.FileHandleFlag"},
        {nullptr, "PySide6.QtCore.QFileDevice.FileTime"},
        {nullptr, "PySide6.QtCore.QFileDevice.MemoryMapFlag"},
        {nullptr, "PySide6.QtCore.QFileDevice.Permission"},
        {nullptr, "PySide6.QtCore.QFileInfo"},
        {nullptr, "PySide6.QtCore.QFileSelector"},
        {nullptr, "PySide6.QtCore.QFileSystemWatcher"},
        {nullptr, "PySide6.QtCore.QAbstractItemModel.CheckIndexOptions"},
        {nullptr, "PySide6.QtCore.QBluetoothPermission.CommunicationModes"},
        {nullptr, "PySide6.QtCore.QByteArray.Base64Options"},
        {nullptr, "PySide6.QtCore.QCborValue.DiagnosticNotationOptions"},
        {nullptr, "PySide6.QtCore.QCborValue.EncodingOptions"},
        {nullptr, "PySide6.QtCore.QCommandLineOption.Flags"},
        {nullptr, "PySide6.QtCore.QDir.Filters"},
        {nullptr, "PySide6.QtCore.QDir.SortFlags"},
        {nullptr, "PySide6.QtCore.QDirIterator.IteratorFlags"},
        {nullptr, "PySide6.QtCore.QEventLoop.ProcessEventsFlags"},
        {nullptr, "PySide6.QtCore.QFileDevice.FileHandleFlags"},
        {nullptr, "PySide6.QtCore.QFileDevice.MemoryMapFlags"},
        {nullptr, "PySide6.QtCore.QFileDevice.Permissions"},
        {nullptr, "PySide6.QtCore.QIODeviceBase.OpenMode"},
        {nullptr, "PySide6.QtCore.QItemSelectionModel.SelectionFlags"},
        {nullptr, "PySide6.QtCore.QLibrary.LoadHints"},
        {nullptr, "PySide6.QtCore.QLocale.DataSizeFormats"},
        {nullptr, "PySide6.QtCore.QLocale.LanguageCodeTypes"},
        {nullptr, "PySide6.QtCore.QLocale.NumberOptions"},
        {nullptr, "PySide6.QtCore.QMetaType.TypeFlags"},
        {nullptr, "PySide6.QtCore.QProcess.UnixProcessFlags"},
        {nullptr, "PySide6.QtCore.QRegularExpression.MatchOptions"},
        {nullptr, "PySide6.QtCore.QRegularExpression.PatternOptions"},
        {nullptr, "PySide6.QtCore.QRegularExpression.WildcardConversionOptions"},
        {nullptr, "PySide6.QtCore.QStandardPaths.LocateOptions"},
        {nullptr, "PySide6.QtCore.QStringConverterBase.Flags"},
        {nullptr, "PySide6.QtCore.QTextBoundaryFinder.BoundaryReasons"},
        {nullptr, "PySide6.QtCore.QTextStream.NumberFlags"},
        {nullptr, "PySide6.QtCore.QUrl.AceProcessingOptions"},
        {nullptr, "PySide6.QtCore.QUrl.FormattingOptions"},
        {nullptr, "+++ unknown entry #131 in QtCore"},
        {nullptr, "PySide6.QtCore.QUrl.UserInputResolutionOptions"},
        {nullptr, "PySide6.QtCore.Qt.Alignment"},
        {nullptr, "PySide6.QtCore.Qt.ApplicationStates"},
        {nullptr, "PySide6.QtCore.Qt.DockWidgetAreas"},
        {nullptr, "PySide6.QtCore.Qt.DropActions"},
        {nullptr, "PySide6.QtCore.Qt.Edges"},
        {nullptr, "PySide6.QtCore.Qt.FindChildOptions"},
        {nullptr, "PySide6.QtCore.Qt.GestureFlags"},
        {nullptr, "PySide6.QtCore.Qt.ImageConversionFlags"},
        {nullptr, "PySide6.QtCore.Qt.InputMethodHints"},
        {nullptr, "PySide6.QtCore.Qt.InputMethodQueries"},
        {nullptr, "PySide6.QtCore.Qt.ItemFlags"},
        {nullptr, "PySide6.QtCore.Qt.KeyboardModifiers"},
        {nullptr, "PySide6.QtCore.Qt.MatchFlags"},
        {nullptr, "PySide6.QtCore.Qt.MouseButtons"},
        {nullptr, "PySide6.QtCore.Qt.MouseEventFlags"},
        {nullptr, "PySide6.QtCore.Qt.Orientations"},
        {nullptr, "PySide6.QtCore.Qt.ScreenOrientations"},
        {nullptr, "PySide6.QtCore.Qt.SplitBehavior"},
        {nullptr, "PySide6.QtCore.Qt.TextInteractionFlags"},
        {nullptr, "PySide6.QtCore.Qt.ToolBarAreas"},
        {nullptr, "PySide6.QtCore.Qt.TouchPointStates"},
        {nullptr, "PySide6.QtCore.Qt.WindowStates"},
        {nullptr, "PySide6.QtCore.Qt.WindowFlags"},
        {nullptr, "PySide6.QtCore.QFutureInterfaceBase"},
        {nullptr, "PySide6.QtCore.QFutureInterfaceBase.CancelMode"},
        {nullptr, "PySide6.QtCore.QFutureInterfaceBase.State"},
        {nullptr, "PySide6.QtCore.QGenericArgument"},
        {nullptr, "PySide6.QtCore.QGenericReturnArgument"},
        {nullptr, "PySide6.QtCore.QHashSeed"},
        {nullptr, "PySide6.QtCore.QIODevice"},
        {nullptr, "PySide6.QtCore.QIODeviceBase"},
        {nullptr, "PySide6.QtCore.QIODeviceBase.OpenModeFlag"},
        {nullptr, "PySide6.QtCore.QIdentityProxyModel"},
        {nullptr, "PySide6.QtCore.QItemSelection"},
        {nullptr, "PySide6.QtCore.QItemSelectionModel"},
        {nullptr, "PySide6.QtCore.QItemSelectionModel.SelectionFlag"},
        {nullptr, "PySide6.QtCore.QItemSelectionRange"},
        {nullptr, "PySide6.QtCore.QJsonArray"},
        {nullptr, "PySide6.QtCore.QJsonDocument"},
        {nullptr, "PySide6.QtCore.QJsonDocument.JsonFormat"},
        {nullptr, "PySide6.QtCore.QJsonParseError"},
        {nullptr, "PySide6.QtCore.QJsonParseError.ParseError"},
        {nullptr, "PySide6.QtCore.QJsonValue"},
        {nullptr, "PySide6.QtCore.QJsonValue.Type"},
        {nullptr, "PySide6.QtCore.QKeyCombination"},
        {nullptr, "PySide6.QtCore.QLibrary"},
        {nullptr, "PySide6.QtCore.QLibrary.LoadHint"},
        {nullptr, "PySide6.QtCore.QLibraryInfo"},
        {nullptr, "PySide6.QtCore.QLibraryInfo.LibraryPath"},
        {nullptr, "PySide6.QtCore.QLine"},
        {nullptr, "PySide6.QtCore.QLineF"},
        {nullptr, "PySide6.QtCore.QLineF.IntersectionType"},
        {nullptr, "PySide6.QtCore.QLocale"},
        {nullptr, "PySide6.QtCore.QLocale.Country"},
        {nullptr, "PySide6.QtCore.QLocale.DataSizeFormat"},
        {nullptr, "PySide6.QtCore.QLocale.FloatingPointPrecisionOption"},
        {nullptr, "PySide6.QtCore.QLocale.FormatType"},
        {nullptr, "PySide6.QtCore.QLocale.Language"},
        {nullptr, "PySide6.QtCore.QLocale.LanguageCodeType"},
        {nullptr, "PySide6.QtCore.QLocale.MeasurementSystem"},
        {nullptr, "PySide6.QtCore.QLocale.NumberOption"},
        {nullptr, "PySide6.QtCore.QLocale.TagSeparator"},
        {nullptr, "PySide6.QtCore.QLocationPermission"},
        {nullptr, "PySide6.QtCore.QLocationPermission.Accuracy"},
        {nullptr, "PySide6.QtCore.QLocationPermission.Availability"},
        {nullptr, "PySide6.QtCore.QLockFile"},
        {nullptr, "PySide6.QtCore.QLockFile.LockError"},
        {nullptr, "PySide6.QtCore.QLoggingCategory"},
        {nullptr, "PySide6.QtCore.QMargins"},
        {nullptr, "PySide6.QtCore.QMarginsF"},
        {nullptr, "PySide6.QtCore.QMessageAuthenticationCode"},
        {nullptr, "PySide6.QtCore.QMessageLogContext"},
        {nullptr, "PySide6.QtCore.QMetaClassInfo"},
        {nullptr, "PySide6.QtCore.QMetaEnum"},
        {nullptr, "PySide6.QtCore.QMetaMethod"},
        {nullptr, "PySide6.QtCore.QMetaMethod.Access"},
        {nullptr, "PySide6.QtCore.QMetaMethod.MethodType"},
        {nullptr, "PySide6.QtCore.QMetaObject"},
        {nullptr, "PySide6.QtCore.QMetaObject.Call"},
        {nullptr, "PySide6.QtCore.QMetaObject.Connection"},
        {nullptr, "PySide6.QtCore.QMetaProperty"},
        {nullptr, "PySide6.QtCore.QMetaType"},
        {nullptr, "PySide6.QtCore.QMetaType.Type"},
        {nullptr, "PySide6.QtCore.QMetaType.TypeFlag"},
        {nullptr, "PySide6.QtCore.QMicrophonePermission"},
        {nullptr, "PySide6.QtCore.QMimeData"},
        {nullptr, "PySide6.QtCore.QMimeDatabase"},
        {nullptr, "PySide6.QtCore.QMimeDatabase.MatchMode"},
        {nullptr, "PySide6.QtCore.QMimeType"},
        {nullptr, "PySide6.QtCore.QModelIndex"},
        {nullptr, "PySide6.QtCore.QModelRoleData"},
        {nullptr, "PySide6.QtCore.QMutex"},
        {nullptr, "PySide6.QtCore.QNativeIpcKey"},
        {nullptr, "PySide6.QtCore.QNativeIpcKey.Type"},
        {nullptr, "PySide6.QtCore.QObject"},
        {nullptr, "PySide6.QtCore.QOperatingSystemVersion"},
        {nullptr, "PySide6.QtCore.QOperatingSystemVersionBase"},
        {nullptr, "PySide6.QtCore.QOperatingSystemVersionBase.OSType"},
        {nullptr, "PySide6.QtCore.QParallelAnimationGroup"},
        {nullptr, "PySide6.QtCore.QPauseAnimation"},
        {nullptr, "PySide6.QtCore.QPermission"},
        {nullptr, "PySide6.QtCore.QPersistentModelIndex"},
        {nullptr, "PySide6.QtCore.QPluginLoader"},
        {nullptr, "PySide6.QtCore.QPoint"},
        {nullptr, "PySide6.QtCore.QPointF"},
        {nullptr, "PySide6.QtCore.QProcess"},
        {nullptr, "PySide6.QtCore.QProcess.ExitStatus"},
        {nullptr, "PySide6.QtCore.QProcess.InputChannelMode"},
        {nullptr, "PySide6.QtCore.QProcess.ProcessChannel"},
        {nullptr, "PySide6.QtCore.QProcess.ProcessChannelMode"},
        {nullptr, "PySide6.QtCore.QProcess.ProcessError"},
        {nullptr, "PySide6.QtCore.QProcess.ProcessState"},
        {nullptr, "PySide6.QtCore.QProcess.UnixProcessFlag"},
        {nullptr, "PySide6.QtCore.QProcess.UnixProcessParameters"},
        {nullptr, "PySide6.QtCore.QProcessEnvironment"},
        {nullptr, "PySide6.QtCore.QProcessEnvironment.Initialization"},
        {nullptr, "PySide6.QtCore.QPropertyAnimation"},
        {nullptr, "PySide6.QtCore.QRandomGenerator"},
        {nullptr, "PySide6.QtCore.QRandomGenerator64"},
        {nullptr, "PySide6.QtCore.QReadLocker"},
        {nullptr, "PySide6.QtCore.QReadWriteLock"},
        {nullptr, "PySide6.QtCore.QReadWriteLock.RecursionMode"},
        {nullptr, "PySide6.QtCore.QRect"},
        {nullptr, "PySide6.QtCore.QRectF"},
        {nullptr, "PySide6.QtCore.QRecursiveMutex"},
        {nullptr, "PySide6.QtCore.QRegularExpression"},
        {nullptr, "PySide6.QtCore.QRegularExpression.MatchOption"},
        {nullptr, "PySide6.QtCore.QRegularExpression.MatchType"},
        {nullptr, "PySide6.QtCore.QRegularExpression.PatternOption"},
        {nullptr, "PySide6.QtCore.QRegularExpression.WildcardConversionOption"},
        {nullptr, "PySide6.QtCore.QRegularExpressionMatch"},
        {nullptr, "PySide6.QtCore.QRegularExpressionMatchIterator"},
        {nullptr, "PySide6.QtCore.QResource"},
        {nullptr, "PySide6.QtCore.QResource.Compression"},
        {nullptr, "PySide6.QtCore.QRunnable"},
        {nullptr, "PySide6.QtCore.QSaveFile"},
        {nullptr, "PySide6.QtCore.QSemaphore"},
        {nullptr, "PySide6.QtCore.QSemaphoreReleaser"},
        {nullptr, "PySide6.QtCore.QSequentialAnimationGroup"},
        {nullptr, "PySide6.QtCore.QSettings"},
        {nullptr, "PySide6.QtCore.QSettings.Format"},
        {nullptr, "PySide6.QtCore.QSettings.Scope"},
        {nullptr, "PySide6.QtCore.QSettings.Status"},
        {nullptr, "PySide6.QtCore.QSharedMemory"},
        {nullptr, "PySide6.QtCore.QSharedMemory.AccessMode"},
        {nullptr, "PySide6.QtCore.QSharedMemory.SharedMemoryError"},
        {nullptr, "PySide6.QtCore.QSignalBlocker"},
        {nullptr, "PySide6.QtCore.QSignalMapper"},
        {nullptr, "PySide6.QtCore.QSize"},
        {nullptr, "PySide6.QtCore.QSizeF"},
        {nullptr, "PySide6.QtCore.QSocketDescriptor"},
        {nullptr, "PySide6.QtCore.QSocketNotifier"},
        {nullptr, "PySide6.QtCore.QSocketNotifier.Type"},
        {nullptr, "PySide6.QtCore.QSortFilterProxyModel"},
        {nullptr, "PySide6.QtCore.QStandardPaths"},
        {nullptr, "PySide6.QtCore.QStandardPaths.LocateOption"},
        {nullptr, "PySide6.QtCore.QStandardPaths.StandardLocation"},
        {nullptr, "PySide6.QtCore.QStorageInfo"},
        {nullptr, "PySide6.QtCore.QStringConverter"},
        {nullptr, "PySide6.QtCore.QStringConverter.Encoding"},
        {nullptr, "PySide6.QtCore.QStringConverterBase"},
        {nullptr, "PySide6.QtCore.QStringConverterBase.Flag"},
        {nullptr, "PySide6.QtCore.QStringConverterBase.State"},
        {nullptr, "PySide6.QtCore.QStringDecoder"},
        {nullptr, "PySide6.QtCore.QStringEncoder"},
        {nullptr, "PySide6.QtCore.QStringListModel"},
        {nullptr, "PySide6.QtCore.QSysInfo"},
        {nullptr, "PySide6.QtCore.QSysInfo.Endian"},
        {nullptr, "PySide6.QtCore.QSysInfo.Sizes"},
        {nullptr, "PySide6.QtCore.QSystemSemaphore"},
        {nullptr, "PySide6.QtCore.QSystemSemaphore.AccessMode"},
        {nullptr, "PySide6.QtCore.QSystemSemaphore.SystemSemaphoreError"},
        {nullptr, "PySide6.QtCore.QTemporaryDir"},
        {nullptr, "PySide6.QtCore.QTemporaryFile"},
        {nullptr, "PySide6.QtCore.QTextBoundaryFinder"},
        {nullptr, "PySide6.QtCore.QTextBoundaryFinder.BoundaryReason"},
        {nullptr, "PySide6.QtCore.QTextBoundaryFinder.BoundaryType"},
        {nullptr, "PySide6.QtCore.QTextStream"},
        {nullptr, "PySide6.QtCore.QTextStream.FieldAlignment"},
        {nullptr, "PySide6.QtCore.QTextStream.NumberFlag"},
        {nullptr, "PySide6.QtCore.QTextStream.RealNumberNotation"},
        {nullptr, "PySide6.QtCore.QTextStream.Status"},
        {nullptr, "PySide6.QtCore.QTextStreamManipulator"},
        {nullptr, "PySide6.QtCore.QThread"},
        {nullptr, "PySide6.QtCore.QThread.Priority"},
        {nullptr, "PySide6.QtCore.QThreadPool"},
        {nullptr, "PySide6.QtCore.QTime"},
        {nullptr, "PySide6.QtCore.QTimeLine"},
        {nullptr, "PySide6.QtCore.QTimeLine.Direction"},
        {nullptr, "PySide6.QtCore.QTimeLine.State"},
        {nullptr, "PySide6.QtCore.QTimeZone"},
        {nullptr, "PySide6.QtCore.QTimeZone.Initialization"},
        {nullptr, "PySide6.QtCore.QTimeZone.NameType"},
        {nullptr, "PySide6.QtCore.QTimeZone.OffsetData"},
        {nullptr, "PySide6.QtCore.QTimeZone.TimeType"},
        {nullptr, "PySide6.QtCore.QTimer"},
        {nullptr, "PySide6.QtCore.QTimerEvent"},
        {nullptr, "PySide6.QtCore.QTranslator"},
        {nullptr, "PySide6.QtCore.QTransposeProxyModel"},
        {nullptr, "PySide6.QtCore.QUrl"},
        {nullptr, "PySide6.QtCore.QUrl.AceProcessingOption"},
        {nullptr, "PySide6.QtCore.QUrl.ComponentFormattingOption"},
        {nullptr, "PySide6.QtCore.QUrl.ParsingMode"},
        {nullptr, "PySide6.QtCore.QUrl.UrlFormattingOption"},
        {nullptr, "PySide6.QtCore.QUrl.UserInputResolutionOption"},
        {nullptr, "PySide6.QtCore.QUrlQuery"},
        {nullptr, "PySide6.QtCore.QUuid"},
        {nullptr, "PySide6.QtCore.QUuid.StringFormat"},
        {nullptr, "PySide6.QtCore.QUuid.Variant"},
        {nullptr, "PySide6.QtCore.QUuid.Version"},
        {nullptr, "PySide6.QtCore.QVariantAnimation"},
        {nullptr, "PySide6.QtCore.QVersionNumber"},
        {nullptr, "PySide6.QtCore.QWaitCondition"},
        {nullptr, "PySide6.QtCore.QWriteLocker"},
        {nullptr, "PySide6.QtCore.QXmlStreamAttribute"},
        {nullptr, "PySide6.QtCore.QXmlStreamAttributes"},
        {nullptr, "PySide6.QtCore.QXmlStreamEntityDeclaration"},
        {nullptr, "PySide6.QtCore.QXmlStreamEntityResolver"},
        {nullptr, "PySide6.QtCore.QXmlStreamNamespaceDeclaration"},
        {nullptr, "PySide6.QtCore.QXmlStreamNotationDeclaration"},
        {nullptr, "PySide6.QtCore.QXmlStreamReader"},
        {nullptr, "PySide6.QtCore.QXmlStreamReader.Error"},
        {nullptr, "PySide6.QtCore.QXmlStreamReader.ReadElementTextBehaviour"},
        {nullptr, "PySide6.QtCore.QXmlStreamReader.TokenType"},
        {nullptr, "PySide6.QtCore.QXmlStreamWriter"},
        {nullptr, "PySide6.QtCore.Qt"},
        {nullptr, "PySide6.QtCore.Qt.AlignmentFlag"},
        {nullptr, "PySide6.QtCore.Qt.AnchorPoint"},
        {nullptr, "PySide6.QtCore.Qt.ApplicationAttribute"},
        {nullptr, "PySide6.QtCore.Qt.ApplicationState"},
        {nullptr, "PySide6.QtCore.Qt.ArrowType"},
        {nullptr, "PySide6.QtCore.Qt.AspectRatioMode"},
        {nullptr, "PySide6.QtCore.Qt.Axis"},
        {nullptr, "PySide6.QtCore.Qt.BGMode"},
        {nullptr, "PySide6.QtCore.Qt.BrushStyle"},
        {nullptr, "PySide6.QtCore.Qt.CaseSensitivity"},
        {nullptr, "PySide6.QtCore.Qt.CheckState"},
        {nullptr, "PySide6.QtCore.Qt.ChecksumType"},
        {nullptr, "PySide6.QtCore.Qt.ClipOperation"},
        {nullptr, "PySide6.QtCore.Qt.ColorScheme"},
        {nullptr, "PySide6.QtCore.Qt.ConnectionType"},
        {nullptr, "PySide6.QtCore.Qt.ContextMenuPolicy"},
        {nullptr, "PySide6.QtCore.Qt.CoordinateSystem"},
        {nullptr, "PySide6.QtCore.Qt.Corner"},
        {nullptr, "PySide6.QtCore.Qt.CursorShape"},
        {nullptr, "PySide6.QtCore.Qt.DateFormat"},
        {nullptr, "PySide6.QtCore.Qt.DayOfWeek"},
        {nullptr, "PySide6.QtCore.Qt.DockWidgetArea"},
        {nullptr, "PySide6.QtCore.Qt.DockWidgetAreaSizes"},
        {nullptr, "PySide6.QtCore.Qt.DropAction"},
        {nullptr, "PySide6.QtCore.Qt.Edge"},
        {nullptr, "PySide6.QtCore.Qt.EnterKeyType"},
        {nullptr, "PySide6.QtCore.Qt.EventPriority"},
        {nullptr, "PySide6.QtCore.Qt.FillRule"},
        {nullptr, "PySide6.QtCore.Qt.FindChildOption"},
        {nullptr, "PySide6.QtCore.Qt.FocusPolicy"},
        {nullptr, "PySide6.QtCore.Qt.FocusReason"},
        {nullptr, "PySide6.QtCore.Qt.GestureFlag"},
        {nullptr, "PySide6.QtCore.Qt.GestureState"},
        {nullptr, "PySide6.QtCore.Qt.GestureType"},
        {nullptr, "PySide6.QtCore.Qt.GlobalColor"},
        {nullptr, "PySide6.QtCore.Qt.HighDpiScaleFactorRoundingPolicy"},
        {nullptr, "PySide6.QtCore.Qt.HitTestAccuracy"},
        {nullptr, "PySide6.QtCore.Qt.ImageConversionFlag"},
        {nullptr, "PySide6.QtCore.Qt.InputMethodHint"},
        {nullptr, "PySide6.QtCore.Qt.InputMethodQuery"},
        {nullptr, "PySide6.QtCore.Qt.ItemDataRole"},
        {nullptr, "PySide6.QtCore.Qt.ItemFlag"},
        {nullptr, "PySide6.QtCore.Qt.ItemSelectionMode"},
        {nullptr, "PySide6.QtCore.Qt.ItemSelectionOperation"},
        {nullptr, "PySide6.QtCore.Qt.Key"},
        {nullptr, "PySide6.QtCore.Qt.KeyboardModifier"},
        {nullptr, "PySide6.QtCore.Qt.LayoutDirection"},
        {nullptr, "PySide6.QtCore.Qt.MaskMode"},
        {nullptr, "PySide6.QtCore.Qt.MatchFlag"},
        {nullptr, "PySide6.QtCore.Qt.Modifier"},
        {nullptr, "PySide6.QtCore.Qt.MouseButton"},
        {nullptr, "PySide6.QtCore.Qt.MouseEventFlag"},
        {nullptr, "PySide6.QtCore.Qt.MouseEventSource"},
        {nullptr, "PySide6.QtCore.Qt.NativeGestureType"},
        {nullptr, "PySide6.QtCore.Qt.NavigationMode"},
        {nullptr, "PySide6.QtCore.Qt.Orientation"},
        {nullptr, "PySide6.QtCore.Qt.PenCapStyle"},
        {nullptr, "PySide6.QtCore.Qt.PenJoinStyle"},
        {nullptr, "PySide6.QtCore.Qt.PenStyle"},
        {nullptr, "PySide6.QtCore.Qt.PermissionStatus"},
        {nullptr, "PySide6.QtCore.Qt.ReturnByValueConstant"},
        {nullptr, "PySide6.QtCore.Qt.ScreenOrientation"},
        {nullptr, "PySide6.QtCore.Qt.ScrollBarPolicy"},
        {nullptr, "PySide6.QtCore.Qt.ScrollPhase"},
        {nullptr, "PySide6.QtCore.Qt.ShortcutContext"},
        {nullptr, "PySide6.QtCore.Qt.SizeHint"},
        {nullptr, "PySide6.QtCore.Qt.SizeMode"},
        {nullptr, "PySide6.QtCore.Qt.SortOrder"},
        {nullptr, "PySide6.QtCore.Qt.SplitBehaviorFlags"},
        {nullptr, "PySide6.QtCore.Qt.TabFocusBehavior"},
        {nullptr, "PySide6.QtCore.Qt.TextElideMode"},
        {nullptr, "PySide6.QtCore.Qt.TextFlag"},
        {nullptr, "PySide6.QtCore.Qt.TextFormat"},
        {nullptr, "PySide6.QtCore.Qt.TextInteractionFlag"},
        {nullptr, "PySide6.QtCore.Qt.TileRule"},
        {nullptr, "PySide6.QtCore.Qt.TimeSpec"},
        {nullptr, "PySide6.QtCore.Qt.TimerType"},
        {nullptr, "PySide6.QtCore.Qt.ToolBarArea"},
        {nullptr, "PySide6.QtCore.Qt.ToolBarAreaSizes"},
        {nullptr, "PySide6.QtCore.Qt.ToolButtonStyle"},
        {nullptr, "PySide6.QtCore.Qt.TouchPointState"},
        {nullptr, "PySide6.QtCore.Qt.TransformationMode"},
        {nullptr, "PySide6.QtCore.Qt.UIEffect"},
        {nullptr, "PySide6.QtCore.Qt.WhiteSpaceMode"},
        {nullptr, "PySide6.QtCore.Qt.WidgetAttribute"},
        {nullptr, "PySide6.QtCore.Qt.WindowFrameSection"},
        {nullptr, "PySide6.QtCore.Qt.WindowModality"},
        {nullptr, "PySide6.QtCore.Qt.WindowState"},
        {nullptr, "PySide6.QtCore.Qt.WindowType"},
        {nullptr, "+++ unknown entry #448 in QtCore"},
        {nullptr, "PySide6.QtCore.QGenericArgumentHolder"},
        {nullptr, "PySide6.QtCore.QGenericReturnArgumentHolder"},
        {nullptr, "PySide6.QtCore.QIOPipe"},
        {nullptr, "PySide6.QtCore.QMutexLocker"},
        {nullptr, "PySide6.QtCore.QtMsgType"},
        {nullptr, "PySide6.QtCore.QCoreApplication.ApplicationFlags"},
        {nullptr, "PySide6.QtCore.QLocale.CurrencySymbolFormat"},
        {nullptr, "PySide6.QtCore.QLocale.QuotationStyle"},
        {nullptr, "PySide6.QtCore.QLocale.Script"},
        {nullptr, "PySide6.QtCore.Qt.CursorMoveStyle"},
        {nullptr, nullptr}
    };
    // The new global structure consisting of (type, name) pairs.
    SbkPySide6_QtCoreTypeStructs = cppApi;
    // The backward compatible alias with upper case indexes.
    SbkPySide6_QtCoreTypes = reinterpret_cast<PyTypeObject **>(cppApi);

    // Create an array of primitive type converters for the current module.
    static SbkConverter *sbkConverters[SBK_QtCore_CONVERTERS_IDX_COUNT];
    SbkPySide6_QtCoreTypeConverters = sbkConverters;

    PyObject *module = Shiboken::Module::create("QtCore", &moduledef);

    // Make module available from global scope
    SbkPySide6_QtCoreModuleObject = module;

    // Initialize classes in the type system
    Shiboken::Module::AddTypeCreationFunction(module, "Qt", init_QtCoreQt);
    Shiboken::Module::AddTypeCreationFunction(module, "QXmlStreamWriter", init_QXmlStreamWriter);
    Shiboken::Module::AddTypeCreationFunction(module, "QXmlStreamReader", init_QXmlStreamReader);
    Shiboken::Module::AddTypeCreationFunction(module, "QXmlStreamNotationDeclaration", init_QXmlStreamNotationDeclaration);
    Shiboken::Module::AddTypeCreationFunction(module, "QXmlStreamNamespaceDeclaration", init_QXmlStreamNamespaceDeclaration);
    Shiboken::Module::AddTypeCreationFunction(module, "QXmlStreamEntityResolver", init_QXmlStreamEntityResolver);
    Shiboken::Module::AddTypeCreationFunction(module, "QXmlStreamEntityDeclaration", init_QXmlStreamEntityDeclaration);
    Shiboken::Module::AddTypeCreationFunction(module, "QXmlStreamAttributes", init_QXmlStreamAttributes);
    Shiboken::Module::AddTypeCreationFunction(module, "QXmlStreamAttribute", init_QXmlStreamAttribute);
#if QT_CONFIG(thread)
    Shiboken::Module::AddTypeCreationFunction(module, "QWriteLocker", init_QWriteLocker);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QVersionNumber", init_QVersionNumber);
    Shiboken::Module::AddTypeCreationFunction(module, "QUuid", init_QUuid);
    Shiboken::Module::AddTypeCreationFunction(module, "QUrlQuery", init_QUrlQuery);
    Shiboken::Module::AddTypeCreationFunction(module, "QTime", init_QTime);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextStreamManipulator", init_QTextStreamManipulator);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextBoundaryFinder", init_QTextBoundaryFinder);
    Shiboken::Module::AddTypeCreationFunction(module, "QTemporaryDir", init_QTemporaryDir);
#ifndef QT_NO_SYSTEMSEMAPHORE
    Shiboken::Module::AddTypeCreationFunction(module, "QSystemSemaphore", init_QSystemSemaphore);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QSysInfo", init_QSysInfo);
    Shiboken::Module::AddTypeCreationFunction(module, "QStringConverterBase", init_QStringConverterBase);
    Shiboken::Module::AddTypeCreationFunction(module, "State", init_QStringConverterBase_State, "QStringConverterBase");
    Shiboken::Module::AddTypeCreationFunction(module, "QStringConverter", init_QStringConverter);
    Shiboken::Module::AddTypeCreationFunction(module, "QStringEncoder", init_QStringEncoder);
    Shiboken::Module::AddTypeCreationFunction(module, "QStringDecoder", init_QStringDecoder);
    Shiboken::Module::AddTypeCreationFunction(module, "QStorageInfo", init_QStorageInfo);
    Shiboken::Module::AddTypeCreationFunction(module, "QStandardPaths", init_QStandardPaths);
    Shiboken::Module::AddTypeCreationFunction(module, "QSocketDescriptor", init_QSocketDescriptor);
    Shiboken::Module::AddTypeCreationFunction(module, "QSizeF", init_QSizeF);
    Shiboken::Module::AddTypeCreationFunction(module, "QSize", init_QSize);
    Shiboken::Module::AddTypeCreationFunction(module, "QSignalBlocker", init_QSignalBlocker);
#if QT_CONFIG(thread)
    Shiboken::Module::AddTypeCreationFunction(module, "QSemaphoreReleaser", init_QSemaphoreReleaser);
#endif
#if QT_CONFIG(thread)
    Shiboken::Module::AddTypeCreationFunction(module, "QSemaphore", init_QSemaphore);
#endif
#if QT_CONFIG(thread)
    Shiboken::Module::AddTypeCreationFunction(module, "QRunnable", init_QRunnable);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QRegularExpressionMatchIterator", init_QRegularExpressionMatchIterator);
    Shiboken::Module::AddTypeCreationFunction(module, "QRegularExpressionMatch", init_QRegularExpressionMatch);
    Shiboken::Module::AddTypeCreationFunction(module, "QRegularExpression", init_QRegularExpression);
    Shiboken::Module::AddTypeCreationFunction(module, "QRectF", init_QRectF);
    Shiboken::Module::AddTypeCreationFunction(module, "QRect", init_QRect);
#if QT_CONFIG(thread)
    Shiboken::Module::AddTypeCreationFunction(module, "QReadLocker", init_QReadLocker);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QRandomGenerator", init_QRandomGenerator);
    Shiboken::Module::AddTypeCreationFunction(module, "QRandomGenerator64", init_QRandomGenerator64);
#if QT_CONFIG(processenvironment)
    Shiboken::Module::AddTypeCreationFunction(module, "QProcessEnvironment", init_QProcessEnvironment);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QPointF", init_QPointF);
    Shiboken::Module::AddTypeCreationFunction(module, "QPoint", init_QPoint);
    Shiboken::Module::AddTypeCreationFunction(module, "QPersistentModelIndex", init_QPersistentModelIndex);
#if QT_CONFIG(permissions)
    Shiboken::Module::AddTypeCreationFunction(module, "QPermission", init_QPermission);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QOperatingSystemVersionBase", init_QOperatingSystemVersionBase);
    Shiboken::Module::AddTypeCreationFunction(module, "QOperatingSystemVersion", init_QOperatingSystemVersion);
    Shiboken::Module::AddTypeCreationFunction(module, "QNativeIpcKey", init_QNativeIpcKey);
#if QT_CONFIG(thread)
    Shiboken::Module::AddTypeCreationFunction(module, "QMutexLocker", init_QtCoreHelper_QMutexLocker);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QModelRoleData", init_QModelRoleData);
    Shiboken::Module::AddTypeCreationFunction(module, "QModelIndex", init_QModelIndex);
    Shiboken::Module::AddTypeCreationFunction(module, "QMimeType", init_QMimeType);
    Shiboken::Module::AddTypeCreationFunction(module, "QMimeDatabase", init_QMimeDatabase);
#if QT_CONFIG(permissions)
    Shiboken::Module::AddTypeCreationFunction(module, "QMicrophonePermission", init_QMicrophonePermission);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QMetaType", init_QMetaType);
    Shiboken::Module::AddTypeCreationFunction(module, "QMetaProperty", init_QMetaProperty);
    Shiboken::Module::AddTypeCreationFunction(module, "QMetaEnum", init_QMetaEnum);
    Shiboken::Module::AddTypeCreationFunction(module, "QMetaClassInfo", init_QMetaClassInfo);
    Shiboken::Module::AddTypeCreationFunction(module, "QMessageLogContext", init_QMessageLogContext);
    Shiboken::Module::AddTypeCreationFunction(module, "QMessageAuthenticationCode", init_QMessageAuthenticationCode);
    Shiboken::Module::AddTypeCreationFunction(module, "QMarginsF", init_QMarginsF);
    Shiboken::Module::AddTypeCreationFunction(module, "QMargins", init_QMargins);
    Shiboken::Module::AddTypeCreationFunction(module, "QLoggingCategory", init_QLoggingCategory);
    Shiboken::Module::AddTypeCreationFunction(module, "QLockFile", init_QLockFile);
#if QT_CONFIG(permissions)
    Shiboken::Module::AddTypeCreationFunction(module, "QLocationPermission", init_QLocationPermission);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QLocale", init_QLocale);
#if QT_CONFIG(timezone)
    Shiboken::Module::AddTypeCreationFunction(module, "QTimeZone", init_QTimeZone);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QResource", init_QResource);
    Shiboken::Module::AddTypeCreationFunction(module, "QLineF", init_QLineF);
    Shiboken::Module::AddTypeCreationFunction(module, "QLine", init_QLine);
    Shiboken::Module::AddTypeCreationFunction(module, "QLibraryInfo", init_QLibraryInfo);
    Shiboken::Module::AddTypeCreationFunction(module, "QKeyCombination", init_QKeyCombination);
    Shiboken::Module::AddTypeCreationFunction(module, "QJsonValue", init_QJsonValue);
    Shiboken::Module::AddTypeCreationFunction(module, "QJsonParseError", init_QJsonParseError);
    Shiboken::Module::AddTypeCreationFunction(module, "QJsonDocument", init_QJsonDocument);
    Shiboken::Module::AddTypeCreationFunction(module, "QJsonArray", init_QJsonArray);
    Shiboken::Module::AddTypeCreationFunction(module, "QItemSelectionRange", init_QItemSelectionRange);
    Shiboken::Module::AddTypeCreationFunction(module, "QItemSelection", init_QItemSelection);
    Shiboken::Module::AddTypeCreationFunction(module, "QIODeviceBase", init_QIODeviceBase);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextStream", init_QTextStream);
    Shiboken::Module::AddTypeCreationFunction(module, "QHashSeed", init_QHashSeed);
    Shiboken::Module::AddTypeCreationFunction(module, "QGenericReturnArgumentHolder", init_QtCoreHelper_QGenericReturnArgumentHolder);
    Shiboken::Module::AddTypeCreationFunction(module, "QGenericArgumentHolder", init_QtCoreHelper_QGenericArgumentHolder);
    Shiboken::Module::AddTypeCreationFunction(module, "QGenericArgument", init_QGenericArgument);
    Shiboken::Module::AddTypeCreationFunction(module, "QMetaObject", init_QMetaObject);
    Shiboken::Module::AddTypeCreationFunction(module, "Connection", init_QMetaObject_Connection, "QMetaObject");
    Shiboken::Module::AddTypeCreationFunction(module, "QObject", init_QObject);
    Shiboken::Module::AddTypeCreationFunction(module, "QTranslator", init_QTranslator);
    Shiboken::Module::AddTypeCreationFunction(module, "QTimer", init_QTimer);
    Shiboken::Module::AddTypeCreationFunction(module, "QTimeLine", init_QTimeLine);
#if QT_CONFIG(thread)
    Shiboken::Module::AddTypeCreationFunction(module, "QThreadPool", init_QThreadPool);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QSocketNotifier", init_QSocketNotifier);
    Shiboken::Module::AddTypeCreationFunction(module, "QSignalMapper", init_QSignalMapper);
#ifndef QT_NO_SHAREDMEMORY
    Shiboken::Module::AddTypeCreationFunction(module, "QSharedMemory", init_QSharedMemory);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QSettings", init_QSettings);
    Shiboken::Module::AddTypeCreationFunction(module, "QPluginLoader", init_QPluginLoader);
    Shiboken::Module::AddTypeCreationFunction(module, "QMimeData", init_QMimeData);
    Shiboken::Module::AddTypeCreationFunction(module, "QLibrary", init_QLibrary);
    Shiboken::Module::AddTypeCreationFunction(module, "QItemSelectionModel", init_QItemSelectionModel);
    Shiboken::Module::AddTypeCreationFunction(module, "QIOPipe", init_QtCoreHelper_QIOPipe);
    Shiboken::Module::AddTypeCreationFunction(module, "QIODevice", init_QIODevice);
#if QT_CONFIG(process)
    Shiboken::Module::AddTypeCreationFunction(module, "QProcess", init_QProcess);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "UnixProcessParameters", init_QProcess_UnixProcessParameters, "QProcess");
    Shiboken::Module::AddTypeCreationFunction(module, "QMetaMethod", init_QMetaMethod);
    Shiboken::Module::AddTypeCreationFunction(module, "QGenericReturnArgument", init_QGenericReturnArgument);
#if QT_CONFIG(future)
    Shiboken::Module::AddTypeCreationFunction(module, "QFutureInterfaceBase", init_QFutureInterfaceBase);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QFileSystemWatcher", init_QFileSystemWatcher);
    Shiboken::Module::AddTypeCreationFunction(module, "QFileSelector", init_QFileSelector);
    Shiboken::Module::AddTypeCreationFunction(module, "QFileInfo", init_QFileInfo);
    Shiboken::Module::AddTypeCreationFunction(module, "QFileDevice", init_QFileDevice);
    Shiboken::Module::AddTypeCreationFunction(module, "QSaveFile", init_QSaveFile);
    Shiboken::Module::AddTypeCreationFunction(module, "QFile", init_QFile);
    Shiboken::Module::AddTypeCreationFunction(module, "QTemporaryFile", init_QTemporaryFile);
    Shiboken::Module::AddTypeCreationFunction(module, "QFactoryInterface", init_QFactoryInterface);
    Shiboken::Module::AddTypeCreationFunction(module, "QEventLoop", init_QEventLoop);
    Shiboken::Module::AddTypeCreationFunction(module, "QEvent", init_QEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QTimerEvent", init_QTimerEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QElapsedTimer", init_QElapsedTimer);
    Shiboken::Module::AddTypeCreationFunction(module, "QEasingCurve", init_QEasingCurve);
    Shiboken::Module::AddTypeCreationFunction(module, "QDynamicPropertyChangeEvent", init_QDynamicPropertyChangeEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QDirIterator", init_QDirIterator);
    Shiboken::Module::AddTypeCreationFunction(module, "QDir", init_QDir);
    Shiboken::Module::AddTypeCreationFunction(module, "QDeadlineTimer", init_QDeadlineTimer);
#if QT_CONFIG(thread)
    Shiboken::Module::AddTypeCreationFunction(module, "QWaitCondition", init_QWaitCondition);
#endif
#if QT_CONFIG(thread)
    Shiboken::Module::AddTypeCreationFunction(module, "QThread", init_QThread);
#endif
#if QT_CONFIG(thread)
    Shiboken::Module::AddTypeCreationFunction(module, "QRecursiveMutex", init_QRecursiveMutex);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QReadWriteLock", init_QReadWriteLock);
    Shiboken::Module::AddTypeCreationFunction(module, "QDateTime", init_QDateTime);
#if QT_CONFIG(timezone)
    Shiboken::Module::AddTypeCreationFunction(module, "OffsetData", init_QTimeZone_OffsetData, "QTimeZone");
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QDate", init_QDate);
    Shiboken::Module::AddTypeCreationFunction(module, "QDataStream", init_QDataStream);
    Shiboken::Module::AddTypeCreationFunction(module, "QCryptographicHash", init_QCryptographicHash);
    Shiboken::Module::AddTypeCreationFunction(module, "QCoreApplication", init_QCoreApplication);
#if QT_CONFIG(permissions)
    Shiboken::Module::AddTypeCreationFunction(module, "QContactsPermission", init_QContactsPermission);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QCommandLineParser", init_QCommandLineParser);
    Shiboken::Module::AddTypeCreationFunction(module, "QCommandLineOption", init_QCommandLineOption);
    Shiboken::Module::AddTypeCreationFunction(module, "QCollatorSortKey", init_QCollatorSortKey);
    Shiboken::Module::AddTypeCreationFunction(module, "QCollator", init_QCollator);
    Shiboken::Module::AddTypeCreationFunction(module, "QChildEvent", init_QChildEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QCborStreamWriter", init_QCborStreamWriter);
    Shiboken::Module::AddTypeCreationFunction(module, "QCborStreamReader", init_QCborStreamReader);
    Shiboken::Module::AddTypeCreationFunction(module, "QCborStringResultString", init_QCborStringResultString);
    Shiboken::Module::AddTypeCreationFunction(module, "QCborMap", init_QCborMap);
    Shiboken::Module::AddTypeCreationFunction(module, "QCborError", init_QCborError);
    Shiboken::Module::AddTypeCreationFunction(module, "QCborParserError", init_QCborParserError);
    Shiboken::Module::AddTypeCreationFunction(module, "QCborArray", init_QCborArray);
#if QT_CONFIG(permissions)
    Shiboken::Module::AddTypeCreationFunction(module, "QCameraPermission", init_QCameraPermission);
#endif
#if QT_CONFIG(permissions)
    Shiboken::Module::AddTypeCreationFunction(module, "QCalendarPermission", init_QCalendarPermission);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QCalendar", init_QCalendar);
    Shiboken::Module::AddTypeCreationFunction(module, "YearMonthDay", init_QCalendar_YearMonthDay, "QCalendar");
    Shiboken::Module::AddTypeCreationFunction(module, "SystemId", init_QCalendar_SystemId, "QCalendar");
    Shiboken::Module::AddTypeCreationFunction(module, "QByteArrayMatcher", init_QByteArrayMatcher);
    Shiboken::Module::AddTypeCreationFunction(module, "QByteArray", init_QByteArray);
    Shiboken::Module::AddTypeCreationFunction(module, "QUrl", init_QUrl);
    Shiboken::Module::AddTypeCreationFunction(module, "QCborValue", init_QCborValue);
    Shiboken::Module::AddTypeCreationFunction(module, "QCborStringResultByteArray", init_QCborStringResultByteArray);
    Shiboken::Module::AddTypeCreationFunction(module, "FromBase64Result", init_QByteArray_FromBase64Result, "QByteArray");
    Shiboken::Module::AddTypeCreationFunction(module, "QBuffer", init_QBuffer);
#if QT_CONFIG(permissions)
    Shiboken::Module::AddTypeCreationFunction(module, "QBluetoothPermission", init_QBluetoothPermission);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QBitArray", init_QBitArray);
    Shiboken::Module::AddTypeCreationFunction(module, "QBasicTimer", init_QBasicTimer);
#if QT_CONFIG(thread)
    Shiboken::Module::AddTypeCreationFunction(module, "QBasicMutex", init_QBasicMutex);
#endif
#if QT_CONFIG(thread)
    Shiboken::Module::AddTypeCreationFunction(module, "QMutex", init_QMutex);
#endif
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractNativeEventFilter", init_QAbstractNativeEventFilter);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractItemModel", init_QAbstractItemModel);
    Shiboken::Module::AddTypeCreationFunction(module, "QConcatenateTablesProxyModel", init_QConcatenateTablesProxyModel);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractTableModel", init_QAbstractTableModel);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractProxyModel", init_QAbstractProxyModel);
    Shiboken::Module::AddTypeCreationFunction(module, "QTransposeProxyModel", init_QTransposeProxyModel);
    Shiboken::Module::AddTypeCreationFunction(module, "QSortFilterProxyModel", init_QSortFilterProxyModel);
    Shiboken::Module::AddTypeCreationFunction(module, "QIdentityProxyModel", init_QIdentityProxyModel);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractListModel", init_QAbstractListModel);
    Shiboken::Module::AddTypeCreationFunction(module, "QStringListModel", init_QStringListModel);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractEventDispatcher", init_QAbstractEventDispatcher);
    Shiboken::Module::AddTypeCreationFunction(module, "TimerInfo", init_QAbstractEventDispatcher_TimerInfo, "QAbstractEventDispatcher");
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractAnimation", init_QAbstractAnimation);
    Shiboken::Module::AddTypeCreationFunction(module, "QVariantAnimation", init_QVariantAnimation);
    Shiboken::Module::AddTypeCreationFunction(module, "QPropertyAnimation", init_QPropertyAnimation);
    Shiboken::Module::AddTypeCreationFunction(module, "QPauseAnimation", init_QPauseAnimation);
    Shiboken::Module::AddTypeCreationFunction(module, "QAnimationGroup", init_QAnimationGroup);
    Shiboken::Module::AddTypeCreationFunction(module, "QSequentialAnimationGroup", init_QSequentialAnimationGroup);
    Shiboken::Module::AddTypeCreationFunction(module, "QParallelAnimationGroup", init_QParallelAnimationGroup);

    // Register converter for type 'PySide6.QtCore.QAnyStringView'.
    SbkPySide6_QtCoreTypeConverters[SBK_QAnyStringView_IDX] = Shiboken::Conversions::createConverter(&PyUnicode_Type, QAnyStringView_CppToPython_QAnyStringView);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QAnyStringView_IDX], "QAnyStringView");

    // Register converter for type 'PySide6.QtCore.QByteArrayView'.
    SbkPySide6_QtCoreTypeConverters[SBK_QByteArrayView_IDX] = Shiboken::Conversions::createConverter(nullptr, QByteArrayView_CppToPython_QByteArrayView);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QByteArrayView_IDX], "QByteArrayView");

    // Register converter for type 'PySide6.QtCore.QChar'.
    SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX] = Shiboken::Conversions::createConverter(nullptr, QChar_CppToPython_QChar);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], "QChar");
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX],
        PyString_PythonToCpp_QChar,
        is_PyString_PythonToCpp_QChar_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX],
        PyLong_PythonToCpp_QChar,
        is_PyLong_PythonToCpp_QChar_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX],
        Py_None_PythonToCpp_QChar,
        is_Py_None_PythonToCpp_QChar_Convertible);

    // Register converter for type 'PySide6.QtCore.QFunctionPointer'.
    SbkPySide6_QtCoreTypeConverters[SBK_QFunctionPointer_IDX] = Shiboken::Conversions::createConverter(&PyLong_Type, QFunctionPointer_CppToPython_QFunctionPointer);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QFunctionPointer_IDX], "QFunctionPointer");
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QFunctionPointer_IDX],
        PyLong_PythonToCpp_QFunctionPointer,
        is_PyLong_PythonToCpp_QFunctionPointer_Convertible);

    // Register converter for type 'PySide6.QtCore.QJsonObject'.
    SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX] = Shiboken::Conversions::createConverter(nullptr, QJsonObject_CppToPython_QJsonObject);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX], "QJsonObject");
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QJsonObject_IDX],
        PyDict_PythonToCpp_QJsonObject,
        is_PyDict_PythonToCpp_QJsonObject_Convertible);

    // Register converter for type 'PySide6.QtCore.QLatin1String'.
    SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX] = Shiboken::Conversions::createConverter(&PyUnicode_Type, QLatin1String_CppToPython_QLatin1String);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], "QLatin1String");
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX],
        PyString_PythonToCpp_QLatin1String,
        is_PyString_PythonToCpp_QLatin1String_Convertible);

    // Register converter for type 'PySide6.QtCore.QString'.
    SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX] = Shiboken::Conversions::createConverter(&PyUnicode_Type, QString_CppToPython_QString);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], "QString");
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX],
        PyUnicode_PythonToCpp_QString,
        is_PyUnicode_PythonToCpp_QString_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX],
        Py_None_PythonToCpp_QString,
        is_Py_None_PythonToCpp_QString_Convertible);

    // Register converter for type 'PySide6.QtCore.QStringList'.
    SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX] = Shiboken::Conversions::createConverter(nullptr, QStringList_CppToPython_QStringList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], "QStringList");
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX],
        PySequence_PythonToCpp_QStringList,
        is_PySequence_PythonToCpp_QStringList_Convertible);

    // Register converter for type 'PySide6.QtCore.QStringView'.
    SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX] = Shiboken::Conversions::createConverter(&PyUnicode_Type, QStringView_CppToPython_QStringView);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QStringView_IDX], "QStringView");

    // Register converter for type 'PySide6.QtCore.QVariant'.
    SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyBaseObject_Type, QVariant_CppToPython_QVariant);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], "QVariant");
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX],
        PyBool_PythonToCpp_QVariant,
        is_PyBool_PythonToCpp_QVariant_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX],
        Py_None_PythonToCpp_QVariant,
        is_Py_None_PythonToCpp_QVariant_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX],
        QString_PythonToCpp_QVariant,
        is_QString_PythonToCpp_QVariant_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX],
        QByteArray_PythonToCpp_QVariant,
        is_QByteArray_PythonToCpp_QVariant_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX],
        PyFloat_PythonToCpp_QVariant,
        is_PyFloat_PythonToCpp_QVariant_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX],
        PyLong_PythonToCpp_QVariant,
        is_PyLong_PythonToCpp_QVariant_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX],
        SbkObject_PythonToCpp_QVariant,
        is_SbkObject_PythonToCpp_QVariant_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX],
        PyDict_PythonToCpp_QVariant,
        is_PyDict_PythonToCpp_QVariant_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX],
        PyList_PythonToCpp_QVariant,
        is_PyList_PythonToCpp_QVariant_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX],
        PyObject_PythonToCpp_QVariant,
        is_PyObject_PythonToCpp_QVariant_Convertible);

    // Register converter for type 'PySide6.QtCore.qintptr'.
    SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX] = Shiboken::Conversions::createConverter(&PyLong_Type, qintptr_CppToPython_qintptr);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], "qintptr");
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX],
        PyLong_PythonToCpp_qintptr,
        is_PyLong_PythonToCpp_qintptr_Convertible);

    // Register converter for type 'PySide6.QtCore.qptrdiff'.
    SbkPySide6_QtCoreTypeConverters[SBK_qptrdiff_IDX] = Shiboken::Conversions::createConverter(&PyLong_Type, qptrdiff_CppToPython_qptrdiff);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_qptrdiff_IDX], "qptrdiff");
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_qptrdiff_IDX],
        PyLong_PythonToCpp_qptrdiff,
        is_PyLong_PythonToCpp_qptrdiff_Convertible);

    // Register converter for type 'PySide6.QtCore.quintptr'.
    SbkPySide6_QtCoreTypeConverters[SBK_quintptr_IDX] = Shiboken::Conversions::createConverter(&PyLong_Type, quintptr_CppToPython_quintptr);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_quintptr_IDX], "quintptr");
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_quintptr_IDX],
        PyLong_PythonToCpp_quintptr,
        is_PyLong_PythonToCpp_quintptr_Convertible);


    // Register converter for type 'QList<int>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_int_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_int_IDX], "QList<int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_int_IDX],
        PySequence_PythonToCpp_QList_int_,
        is_PySequence_PythonToCpp_QList_int__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_int_IDX],
        PythonToCppQIntList,
        isQIntListPythonToCppConvertible);

    // Register converter for type 'QList<QPoint>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QPoint_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QPoint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QPoint_IDX], "QList<QPoint>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QPoint_IDX],
        PySequence_PythonToCpp_QList_QPoint_,
        is_PySequence_PythonToCpp_QList_QPoint__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QPoint_IDX],
        PythonToCppQPointList,
        isQPointListPythonToCppConvertible);

    // Register converter for type 'QList<QPointF>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QPointF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QPointF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QPointF_IDX], "QList<QPointF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QPointF_IDX],
        PySequence_PythonToCpp_QList_QPointF_,
        is_PySequence_PythonToCpp_QList_QPointF__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QPointF_IDX],
        PythonToCppQPointFList,
        isQPointFListPythonToCppConvertible);

    // Register converter for type 'QList<QObject*>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QObjectPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QObjectPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QObjectPTR_IDX], "QList<QObject*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QObjectPTR_IDX],
        PySequence_PythonToCpp_QList_QObjectPTR_,
        is_PySequence_PythonToCpp_QList_QObjectPTR__Convertible);
    // Register converters for type aliases of QList<QObject*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QObjectPTR_IDX], "QObjectList");

    // Register converter for type 'QList<QByteArray>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QByteArray__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX], "QList<QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX],
        PySequence_PythonToCpp_QList_QByteArray_,
        is_PySequence_PythonToCpp_QList_QByteArray__Convertible);
    // Register converters for type aliases of QList<QByteArray>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX], "QByteArrayList");

    // Register converter for type 'QList<QXmlStreamNamespaceDeclaration>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamNamespaceDeclaration_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QXmlStreamNamespaceDeclaration__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamNamespaceDeclaration_IDX], "QList<QXmlStreamNamespaceDeclaration>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamNamespaceDeclaration_IDX],
        PySequence_PythonToCpp_QList_QXmlStreamNamespaceDeclaration_,
        is_PySequence_PythonToCpp_QList_QXmlStreamNamespaceDeclaration__Convertible);
    // Register converters for type aliases of QList<QXmlStreamNamespaceDeclaration>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamNamespaceDeclaration_IDX], "QXmlStreamNamespaceDeclarations");

    // Register converter for type 'QList<QXmlStreamEntityDeclaration>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamEntityDeclaration_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QXmlStreamEntityDeclaration__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamEntityDeclaration_IDX], "QList<QXmlStreamEntityDeclaration>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamEntityDeclaration_IDX],
        PySequence_PythonToCpp_QList_QXmlStreamEntityDeclaration_,
        is_PySequence_PythonToCpp_QList_QXmlStreamEntityDeclaration__Convertible);
    // Register converters for type aliases of QList<QXmlStreamEntityDeclaration>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamEntityDeclaration_IDX], "QXmlStreamEntityDeclarations");

    // Register converter for type 'QList<QXmlStreamNotationDeclaration>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamNotationDeclaration_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QXmlStreamNotationDeclaration__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamNotationDeclaration_IDX], "QList<QXmlStreamNotationDeclaration>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamNotationDeclaration_IDX],
        PySequence_PythonToCpp_QList_QXmlStreamNotationDeclaration_,
        is_PySequence_PythonToCpp_QList_QXmlStreamNotationDeclaration__Convertible);
    // Register converters for type aliases of QList<QXmlStreamNotationDeclaration>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamNotationDeclaration_IDX], "QXmlStreamNotationDeclarations");

    // Register converter for type 'QList<QXmlStreamAttribute>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QXmlStreamAttribute__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX], "QList<QXmlStreamAttribute>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QXmlStreamAttribute_IDX],
        PySequence_PythonToCpp_QList_QXmlStreamAttribute_,
        is_PySequence_PythonToCpp_QList_QXmlStreamAttribute__Convertible);

    // Register converter for type 'std::pair<QString,QString>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_QString_QString_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_QString_QString__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_QString_QString_IDX], "std::pair<QString,QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_QString_QString_IDX],
        PySequence_PythonToCpp_std_pair_QString_QString_,
        is_PySequence_PythonToCpp_std_pair_QString_QString__Convertible);

    // Register converter for type 'QList<std::pair<QString,QString>>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_std_pair_QString_QString_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_std_pair_QString_QString___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_std_pair_QString_QString_IDX], "QList<std::pair<QString,QString>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_std_pair_QString_QString_IDX],
        PySequence_PythonToCpp_QList_std_pair_QString_QString__,
        is_PySequence_PythonToCpp_QList_std_pair_QString_QString___Convertible);

    // Register converter for type 'QList<QStorageInfo>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QStorageInfo_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QStorageInfo__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QStorageInfo_IDX], "QList<QStorageInfo>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QStorageInfo_IDX],
        PySequence_PythonToCpp_QList_QStorageInfo_,
        is_PySequence_PythonToCpp_QList_QStorageInfo__Convertible);

    // Register converter for type 'QList<QMimeType>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QMimeType_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QMimeType__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QMimeType_IDX], "QList<QMimeType>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QMimeType_IDX],
        PySequence_PythonToCpp_QList_QMimeType_,
        is_PySequence_PythonToCpp_QList_QMimeType__Convertible);

    // Register converter for type 'QList<QLocale::Country>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QLocale_Country_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QLocale_Country__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QLocale_Country_IDX], "QList<QLocale::Country>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QLocale_Country_IDX],
        PySequence_PythonToCpp_QList_QLocale_Country_,
        is_PySequence_PythonToCpp_QList_QLocale_Country__Convertible);

    // Register converter for type 'QList<QLocale>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QLocale_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QLocale__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QLocale_IDX], "QList<QLocale>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QLocale_IDX],
        PySequence_PythonToCpp_QList_QLocale_,
        is_PySequence_PythonToCpp_QList_QLocale__Convertible);

    // Register converter for type 'QList<Qt::DayOfWeek>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_Qt_DayOfWeek_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_Qt_DayOfWeek__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_Qt_DayOfWeek_IDX], "QList<Qt::DayOfWeek>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_Qt_DayOfWeek_IDX],
        PySequence_PythonToCpp_QList_Qt_DayOfWeek_,
        is_PySequence_PythonToCpp_QList_Qt_DayOfWeek__Convertible);

    // Register converter for type 'QList<QTimeZone::OffsetData>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QTimeZone_OffsetData_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QTimeZone_OffsetData__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QTimeZone_OffsetData_IDX], "QList<QTimeZone::OffsetData>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QTimeZone_OffsetData_IDX],
        PySequence_PythonToCpp_QList_QTimeZone_OffsetData_,
        is_PySequence_PythonToCpp_QList_QTimeZone_OffsetData__Convertible);
    // Register converters for type aliases of QList<QTimeZone::OffsetData>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QTimeZone_OffsetData_IDX], "QTimeZone::OffsetDataList");

    // Register converter for type 'QList<QVariant>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QVariant__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QVariant_IDX], "QList<QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QVariant_IDX],
        PySequence_PythonToCpp_QList_QVariant_,
        is_PySequence_PythonToCpp_QList_QVariant__Convertible);
    // Register converters for type aliases of QList<QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QVariant_IDX], "QVariantList");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QVariant_IDX], "QVariantList");

    // Register converter for type 'QList<QModelIndex>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QModelIndex_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QModelIndex__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QModelIndex_IDX], "QList<QModelIndex>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QModelIndex_IDX],
        PySequence_PythonToCpp_QList_QModelIndex_,
        is_PySequence_PythonToCpp_QList_QModelIndex__Convertible);
    // Register converters for type aliases of QList<QModelIndex>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QModelIndex_IDX], "QModelIndexList");

    // Register converter for type 'QList<QItemSelectionRange>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QItemSelectionRange__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX], "QList<QItemSelectionRange>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QItemSelectionRange_IDX],
        PySequence_PythonToCpp_QList_QItemSelectionRange_,
        is_PySequence_PythonToCpp_QList_QItemSelectionRange__Convertible);

    // Register converter for type 'QList<QUrl>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QUrl_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QUrl__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QUrl_IDX], "QList<QUrl>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QUrl_IDX],
        PySequence_PythonToCpp_QList_QUrl_,
        is_PySequence_PythonToCpp_QList_QUrl__Convertible);

    // Register converter for type 'QList<QFileInfo>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QFileInfo_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QFileInfo__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QFileInfo_IDX], "QList<QFileInfo>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QFileInfo_IDX],
        PySequence_PythonToCpp_QList_QFileInfo_,
        is_PySequence_PythonToCpp_QList_QFileInfo__Convertible);
    // Register converters for type aliases of QList<QFileInfo>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QFileInfo_IDX], "QFileInfoList");

    // Register converter for type 'QList<QCommandLineOption>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QCommandLineOption_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QCommandLineOption__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QCommandLineOption_IDX], "QList<QCommandLineOption>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QCommandLineOption_IDX],
        PySequence_PythonToCpp_QList_QCommandLineOption_,
        is_PySequence_PythonToCpp_QList_QCommandLineOption__Convertible);

    // Register converter for type 'QHash<QString,QVariant>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QHash_QString_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, QHash_QString_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QHash_QString_QVariant_IDX], "QHash<QString,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QHash_QString_QVariant_IDX],
        PyDict_PythonToCpp_QHash_QString_QVariant_,
        is_PyDict_PythonToCpp_QHash_QString_QVariant__Convertible);
    // Register converters for type aliases of QHash<QString,QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QHash_QString_QVariant_IDX], "QVariantHash");

    // Register converter for type 'QMap<QString,QVariant>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QMap_QString_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, QMap_QString_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QMap_QString_QVariant_IDX], "QMap<QString,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QMap_QString_QVariant_IDX],
        PyDict_PythonToCpp_QMap_QString_QVariant_,
        is_PyDict_PythonToCpp_QMap_QString_QVariant__Convertible);
    // Register converters for type aliases of QMap<QString,QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QMap_QString_QVariant_IDX], "QVariantMap");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QMap_QString_QVariant_IDX], "QSettings::SettingsMap");

    // Register converter for type 'QList<QCborValue>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QCborValue_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QCborValue__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QCborValue_IDX], "QList<QCborValue>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QCborValue_IDX],
        PySequence_PythonToCpp_QList_QCborValue_,
        is_PySequence_PythonToCpp_QList_QCborValue__Convertible);

    // Register converter for type 'QMap<int,QVariant>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QMap_int_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, QMap_int_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QMap_int_QVariant_IDX], "QMap<int,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QMap_int_QVariant_IDX],
        PyDict_PythonToCpp_QMap_int_QVariant_,
        is_PyDict_PythonToCpp_QMap_int_QVariant__Convertible);

    // Register converter for type 'QList<QPersistentModelIndex>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QPersistentModelIndex_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QPersistentModelIndex__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QPersistentModelIndex_IDX], "QList<QPersistentModelIndex>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QPersistentModelIndex_IDX],
        PySequence_PythonToCpp_QList_QPersistentModelIndex_,
        is_PySequence_PythonToCpp_QList_QPersistentModelIndex__Convertible);

    // Register converter for type 'QHash<int,QByteArray>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QHash_int_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, QHash_int_QByteArray__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QHash_int_QByteArray_IDX], "QHash<int,QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QHash_int_QByteArray_IDX],
        PyDict_PythonToCpp_QHash_int_QByteArray_,
        is_PyDict_PythonToCpp_QHash_int_QByteArray__Convertible);

    // Register converter for type 'QList<QAbstractItemModel*>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QAbstractItemModelPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QAbstractItemModelPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QAbstractItemModelPTR_IDX], "QList<QAbstractItemModel*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QAbstractItemModelPTR_IDX],
        PySequence_PythonToCpp_QList_QAbstractItemModelPTR_,
        is_PySequence_PythonToCpp_QList_QAbstractItemModelPTR__Convertible);

    // Register converter for type 'QList<QAbstractEventDispatcher::TimerInfo>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QAbstractEventDispatcher_TimerInfo_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QAbstractEventDispatcher_TimerInfo__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QAbstractEventDispatcher_TimerInfo_IDX], "QList<QAbstractEventDispatcher::TimerInfo>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QAbstractEventDispatcher_TimerInfo_IDX],
        PySequence_PythonToCpp_QList_QAbstractEventDispatcher_TimerInfo_,
        is_PySequence_PythonToCpp_QList_QAbstractEventDispatcher_TimerInfo__Convertible);

    // Register converter for type 'std::pair<double,QVariant>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_double_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_double_QVariant__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_double_QVariant_IDX], "std::pair<double,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_double_QVariant_IDX],
        PySequence_PythonToCpp_std_pair_double_QVariant_,
        is_PySequence_PythonToCpp_std_pair_double_QVariant__Convertible);
    // Register converters for type aliases of std::pair<double,QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_std_pair_double_QVariant_IDX], "QVariantAnimation::KeyValue");

    // Register converter for type 'QList<std::pair<double,QVariant>>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_std_pair_double_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_std_pair_double_QVariant___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_std_pair_double_QVariant_IDX], "QList<std::pair<double,QVariant>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_std_pair_double_QVariant_IDX],
        PySequence_PythonToCpp_QList_std_pair_double_QVariant__,
        is_PySequence_PythonToCpp_QList_std_pair_double_QVariant___Convertible);

    // Register converter for type 'QList<QString>'.
    SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QString_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, QList_QString__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QString_IDX], "QList<QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QString_IDX],
        PySequence_PythonToCpp_QList_QString_,
        is_PySequence_PythonToCpp_QList_QString__Convertible);
    // Register converters for type aliases of QList<QString>'.


    // Opaque container type registration
    PyObject *ob_type{};
    ob_type = reinterpret_cast<PyObject *>(QIntList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QIntList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QPointList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QPointList", ob_type);
    ob_type = reinterpret_cast<PyObject *>(QPointFList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QPointFList", ob_type);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'QCborKnownTags'.
    const char *QCborKnownTags_Initializer[] = {
        "DateTimeString",
        "UnixTime_t",
        "PositiveBignum",
        "NegativeBignum",
        "Decimal",
        "Bigfloat",
        "COSE_Encrypt0",
        "COSE_Mac0",
        "COSE_Sign1",
        "ExpectedBase64url",
        "ExpectedBase64",
        "ExpectedBase16",
        "EncodedCbor",
        "Url",
        "Base64url",
        "Base64",
        "RegularExpression",
        "MimeMessage",
        "Uuid",
        "COSE_Encrypt",
        "COSE_Mac",
        "COSE_Sign",
        "Signature",
        nullptr};
    // "int32_t" used instead of "int"
    constexpr int32_t QCborKnownTags_InitializerValues[] = {
        int32_t(QCborKnownTags::DateTimeString),    //  0x00000000  0
        int32_t(QCborKnownTags::UnixTime_t),        //  0x00000001  1
        int32_t(QCborKnownTags::PositiveBignum),    //  0x00000002  2
        int32_t(QCborKnownTags::NegativeBignum),    //  0x00000003  3
        int32_t(QCborKnownTags::Decimal),           //  0x00000004  4
        int32_t(QCborKnownTags::Bigfloat),          //  0x00000005  5
        int32_t(QCborKnownTags::COSE_Encrypt0),     //  0x00000010  16
        int32_t(QCborKnownTags::COSE_Mac0),         //  0x00000011  17
        int32_t(QCborKnownTags::COSE_Sign1),        //  0x00000012  18
        int32_t(QCborKnownTags::ExpectedBase64url), //  0x00000015  21
        int32_t(QCborKnownTags::ExpectedBase64),    //  0x00000016  22
        int32_t(QCborKnownTags::ExpectedBase16),    //  0x00000017  23
        int32_t(QCborKnownTags::EncodedCbor),       //  0x00000018  24
        int32_t(QCborKnownTags::Url),               //  0x00000020  32
        int32_t(QCborKnownTags::Base64url),         //  0x00000021  33
        int32_t(QCborKnownTags::Base64),            //  0x00000022  34
        int32_t(QCborKnownTags::RegularExpression), //  0x00000023  35
        int32_t(QCborKnownTags::MimeMessage),       //  0x00000024  36
        int32_t(QCborKnownTags::Uuid),              //  0x00000025  37
        int32_t(QCborKnownTags::COSE_Encrypt),      //  0x00000060  96
        int32_t(QCborKnownTags::COSE_Mac),          //  0x00000061  97
        int32_t(QCborKnownTags::COSE_Sign),         //  0x00000062  98
        int32_t(QCborKnownTags::Signature)          //  0x0000d9f7  55799
        };
    EType = Shiboken::Enum::createPythonEnum(module,
        "2:PySide6.QtCore.QCborKnownTags",
        QCborKnownTags_Initializer, QCborKnownTags_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborKnownTags_IDX].type = EType;
    // Register converter for enum 'QCborKnownTags'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCborKnownTags_CppToPython_QCborKnownTags);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCborKnownTags_PythonToCpp_QCborKnownTags,
            is_QCborKnownTags_PythonToCpp_QCborKnownTags_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCborKnownTags");
    }
    // End of 'QCborKnownTags' enum.

    // Initialization of enum 'QCborSimpleType'.
    const char *QCborSimpleType_Initializer[] = {
        "False_",
        "True_",
        "Null",
        "Undefined",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t QCborSimpleType_InitializerValues[] = {
        uint8_t(QCborSimpleType::False),    //  0x14  20
        uint8_t(QCborSimpleType::True),     //  0x15  21
        uint8_t(QCborSimpleType::Null),     //  0x16  22
        uint8_t(QCborSimpleType::Undefined) //  0x17  23
        };
    EType = Shiboken::Enum::createPythonEnum(module,
        "2:PySide6.QtCore.QCborSimpleType",
        QCborSimpleType_Initializer, QCborSimpleType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborSimpleType_IDX].type = EType;
    // Register converter for enum 'QCborSimpleType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCborSimpleType_CppToPython_QCborSimpleType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCborSimpleType_PythonToCpp_QCborSimpleType,
            is_QCborSimpleType_PythonToCpp_QCborSimpleType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCborSimpleType");
    }
    // End of 'QCborSimpleType' enum.

    // Initialization of enum 'QCborTag'.
    const char *QCborTag_Initializer[] = {
        nullptr};
    // "uint8_t" used instead of "unsigned long long"
    const uint8_t *QCborTag_InitializerValues{};
    EType = Shiboken::Enum::createPythonEnum(module,
        "2:PySide6.QtCore.QCborTag",
        QCborTag_Initializer, QCborTag_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborTag_IDX].type = EType;
    // Register converter for enum 'QCborTag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCborTag_CppToPython_QCborTag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCborTag_PythonToCpp_QCborTag,
            is_QCborTag_PythonToCpp_QCborTag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCborTag");
    }
    // End of 'QCborTag' enum.

    // Initialization of enum 'QtMsgType'.
    const char *QtMsgType_Initializer[] = {
        "QtDebugMsg",
        "QtWarningMsg",
        "QtCriticalMsg",
        "QtFatalMsg",
        "QtInfoMsg",
        "QtSystemMsg",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t QtMsgType_InitializerValues[] = {
        uint8_t(QtMsgType::QtDebugMsg),    //  0x00  0
        uint8_t(QtMsgType::QtWarningMsg),  //  0x01  1
        uint8_t(QtMsgType::QtCriticalMsg), //  0x02  2
        uint8_t(QtMsgType::QtFatalMsg),    //  0x03  3
        uint8_t(QtMsgType::QtInfoMsg),     //  0x04  4
        uint8_t(QtMsgType::QtSystemMsg)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(module,
        "2:PySide6.QtCore.QtMsgType",
        QtMsgType_Initializer, QtMsgType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX].type = EType;
    // Register converter for enum 'QtMsgType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QtMsgType_CppToPython_QtMsgType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QtMsgType_PythonToCpp_QtMsgType,
            is_QtMsgType_PythonToCpp_QtMsgType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QtMsgType");
    }
    // End of 'QtMsgType' enum.

    // Register primitive types converters.
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "__caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__clock_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__clockid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_d_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__fsword_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intptr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__sig_atomic_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__socklen_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__syscall_slong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__syscall_ulong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__time_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__useconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "comparison_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "intptr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), "qInternalCallback");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "qint16");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "qint32");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), "qint64");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "qint8");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), "qlonglong");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "qreal");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), "qsizetype");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "quint16");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "quint32");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long long>(), "quint64");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "quint8");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long long>(), "qulonglong");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "register_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uchar");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uint");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "uint16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uint32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uintptr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ulong");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "useconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "ushort");

    Shiboken::Module::registerTypes(module, SbkPySide6_QtCoreTypeStructs);
    Shiboken::Module::registerTypeConverters(module, SbkPySide6_QtCoreTypeConverters);

    // Static field initialization
    init_QOperatingSystemVersionStaticFields(module);
    init_QNativeIpcKeyStaticFields(module);
    init_QLocaleStaticFields(module);
#if QT_CONFIG(timezone)
    init_QTimeZoneStaticFields(module);
#endif
    init_QDeadlineTimerStaticFields(module);

    if (Shiboken::Errors::occurred() != nullptr) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtCore");
    }
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qt-qaddpostroutine)]
    qAddPostRoutine(PySide::globalPostRoutineCallback);
    // END of custom code block [file: ../glue/qtcore.cpp (qt-qaddpostroutine)]
    // ========================================================================
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qt-version)]
    QList<QByteArray> version = QByteArray(qVersion()).split('.');
    PyObject *pyQtVersion = PyTuple_New(3);
    for (int i = 0; i < 3; ++i)
        PyTuple_SET_ITEM(pyQtVersion, i, PyLong_FromLong(version[i].toInt()));
    PyModule_AddObject(module, "__version_info__", pyQtVersion);
    PyModule_AddStringConstant(module, "__version__", qVersion());
    // END of custom code block [file: ../glue/qtcore.cpp (qt-version)]
    // ========================================================================
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qt-module-shutdown)]
    { // Avoid name clash
        Shiboken::AutoDecRef regFunc(static_cast<PyObject *>(nullptr));
        Shiboken::AutoDecRef atexit(Shiboken::Module::import("atexit"));
        if (atexit.isNull()) {
            qWarning("Module atexit not found for registering __moduleShutdown");
            PyErr_Clear();
        } else {
            regFunc.reset(PyObject_GetAttrString(atexit, "register"));
            if (regFunc.isNull()) {
                qWarning("Function atexit.register not found for registering __moduleShutdown");
                PyErr_Clear();
            }
        }
        if (!atexit.isNull() && !regFunc.isNull()){
            PyObject *shutDownFunc = PyObject_GetAttrString(module, "__moduleShutdown");
            Shiboken::AutoDecRef args(PyTuple_New(1));
            PyTuple_SET_ITEM(args, 0, shutDownFunc);
            Shiboken::AutoDecRef retval(PyObject_Call(regFunc, args, 0));
            Q_ASSERT(!retval.isNull());
        }
    }
    // END of custom code block [file: ../glue/qtcore.cpp (qt-module-shutdown)]
    // ========================================================================
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qt-pysideinit)]
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], "unicode");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], "str");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QVariant_IDX], "QVariantList");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QMap_QString_QVariant_IDX], "QVariantMap");

    PySide::registerInternalQtConf();
    PySide::init(module);
    Py_AtExit(QtCoreModuleExit);
    // END of custom code block [file: ../glue/qtcore.cpp (qt-pysideinit)]
    // ========================================================================
    // End of code injection

    qRegisterMetaType< ::QCborKnownTags >("QCborKnownTags");
    qRegisterMetaType< ::QCborSimpleType >("QCborSimpleType");
    qRegisterMetaType< ::QCborTag >("QCborTag");
    qRegisterMetaType< ::QtMsgType >("QtMsgType");
    PySide::registerCleanupFunction(cleanTypesAttributes);

    FinishSignatureInitialization(module, QtCore_SignatureStrings);

    return module;
}
